<?php
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}

if (!class_exists('G5P_Inc_Config_Meta_Boxes')) {
	class G5P_Inc_Config_Meta_Boxes
	{
		/*
	 * loader instances
	 */
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		public function init()
		{
			// Defined Theme Options
			add_filter('gsf_meta_box_config', array($this, 'register_meta_boxes'));
			add_action('do_meta_boxes',array($this,'remove_my_page_meta_boxes'));
		}
		
		public function remove_my_page_meta_boxes() {
			$screen = get_current_screen();
			if ( is_admin() && ($screen->id == 'page') ) {
				global $post;
				$id = $post->ID;
				if (('page' == get_option('show_on_front') && $id == get_option('page_for_posts')) || (class_exists('WooCommerce') && $id == get_option( 'woocommerce_shop_page_id' ))) {
					remove_meta_box( 'gsf_page_setting',$this->getPostType(),'advanced' ); // Author Metabox
				}
			}
		}
		
		public function getPostType()
		{
			return apply_filters('gsf_page_setting_post_type', array('page'));
		}
		
		public function register_meta_boxes($configs)
		{
			$prefix = G5P()->getMetaPrefix();
			
			
			/**
			 * CUSTOM PAGE SETTINGS
			 */
			$configs['gsf_page_setting'] = array(
				'name'      => esc_html__('Page Settings', 'achilles-framework'),
				'post_type' => $this->getPostType(),
				'layout'    => 'inline',
				'section'   => array(
					array(
						'id'     => "{$prefix}section_general",
						'title'  => esc_html__('General', 'achilles-framework'),
						'icon'   => 'dashicons dashicons-admin-site',
						'fields' => array(
							G5P()->configOptions()->get_config_preset(array('id' => "{$prefix}page_preset")),
							array(
								'id'     => "{$prefix}group_layout",
								'type'   => 'group',
								'title'  => esc_html__('Layout', 'achilles-framework'),
								'fields' => array(
									array(
										'id'      => "{$prefix}main_layout",
										'title'   => esc_html__('Site Layout', 'achilles-framework'),
										'type'    => 'image_set',
										'options' => G5P()->settings()->get_main_layout(true),
										'default' => '',
									),
									
									G5P()->configOptions()->get_config_toggle(array(
										'id'       => "{$prefix}content_full_width",
										'title'    => esc_html__('Content Full Width', 'achilles-framework'),
										'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width.', 'achilles-framework'),
										'default'  => '',
									), true),
									
									G5P()->configOptions()->get_config_toggle(array(
										'id'       => "{$prefix}custom_content_padding",
										'title'    => esc_html__('Custom Content Padding', 'achilles-framework'),
										'subtitle' => esc_html__('Turn On this option if you want to custom content padding.', 'achilles-framework'),
										'default'  => ''
									)),
									
									array(
										'id'       => "{$prefix}content_padding",
										'title'    => esc_html__('Content Padding', 'achilles-framework'),
										'subtitle' => esc_html__('Set content padding', 'achilles-framework'),
										'type'     => 'spacing',
										'default'  => array('left' => 0, 'right' => 0, 'top' => 60, 'bottom' => 60),
										'required' => array("{$prefix}custom_content_padding", '=', 'on')
									),
									
									G5P()->configOptions()->get_config_sidebar_layout(array(
										'id' => "{$prefix}sidebar_layout",
									), true),
									G5P()->configOptions()->get_config_sidebar(array(
										'id'       => "{$prefix}sidebar",
										'required' => array("{$prefix}sidebar_layout", '!=', 'none')
									)),
								)
							),
							
							array(
								'id'     => "{$prefix}group_page_title",
								'type'   => 'group',
								'title'  => esc_html__('Page Title', 'achilles-framework'),
								'fields' => array(
									G5P()->configOptions()->get_config_toggle(array(
										'title' => esc_html__('Page Title Enable', 'achilles-framework'),
										'id'    => "{$prefix}page_title_enable"
									), true),
									G5P()->configOptions()->get_config_content_block(array(
										'id'       => "{$prefix}page_title_content_block",
										'desc'     => esc_html__('Specify the Content Block to use as a page title content.', 'achilles-framework'),
										'required' => array("{$prefix}page_title_enable", '!=', 'off')
									), true),
									
									array(
										'title'    => esc_html__('Custom Page title', 'achilles-framework'),
										'id'       => "{$prefix}page_title_content",
										'type'     => 'text',
										'default'  => '',
										'required' => array("{$prefix}page_title_enable", '!=', 'off'),
										'desc'     => esc_html__('Enter custom page title for this page', 'achilles-framework')
									)
								)
							),
							array(
								'title'   => esc_html__('Custom Css Class', 'achilles-framework'),
								'id'      => "{$prefix}css_class",
								'type'    => 'selectize',
								'tags'    => true,
								'default' => '',
								'desc'    => esc_html__('Enter custom class for this page', 'achilles-framework')
							)
						)
					),
					array(
						'id'     => "{$prefix}section_menu",
						'title'  => esc_html__('Menu', 'achilles-framework'),
						'icon'   => 'dashicons dashicons-menu',
						'fields' => array(
							array(
								'id'          => "{$prefix}page_menu",
								'title'       => esc_html__('Page Menu', 'achilles-framework'),
								'type'        => 'selectize',
								'allow_clear' => true,
								'placeholder' => esc_html__('Select Menu', 'achilles-framework'),
								'desc'        => esc_html__('Optionally you can choose to override the menu that is used on the page', 'achilles-framework'),
								'data'        => 'menu'
							),
							array(
								'id'          => "{$prefix}page_mobile_menu",
								'title'       => esc_html__('Page Mobile Menu', 'achilles-framework'),
								'type'        => 'selectize',
								'allow_clear' => true,
								'placeholder' => esc_html__('Select Menu', 'achilles-framework'),
								'desc'        => esc_html__('Optionally you can choose to override the menu mobile that is used on the page', 'achilles-framework'),
								'data'        => 'menu'
							),
							G5P()->configOptions()->get_config_toggle(array(
								'id'    => "{$prefix}is_one_page",
								'title' => esc_html__('Is One Page', 'achilles-framework'),
								'desc'  => esc_html__('Set page style is One Page', 'achilles-framework'),
							))
						)
					),
				
				),
			);
			
			
			/**
			 * CUSTOME POST SETTING
			 */
			$configs['gsf_post_setting'] = array(
				'name'      => esc_html__('Post Settings', 'achilles-framework'),
				'post_type' => array('post'),
				'layout'    => 'inline',
				'section'   => array(
					array(
                        'id' =>  "{$prefix}section_post_general",
                        'title' => esc_html__('General', 'achilles-framework'),
                        'icon' => 'dashicons dashicons-admin-site',
						'fields' => array(
                            array(
                                'id' => "gf_format_video_embed",
                                'title' => esc_html__('Featured Video/Audio Code','oars-framework'),
                                'subtitle' => esc_html__('Paste YouTube, Vimeo or self hosted video URL then player automatically will be generated.','oars-framework'),
                                'type' => 'textarea'
                            ),
                            array(
                                'id' => "gf_format_audio_embed",
                                'title' => esc_html__('Featured Video/Audio Code','oars-framework'),
                                'subtitle' => esc_html__('Paste YouTube, Vimeo or self hosted video URL then player automatically will be generated.','oars-framework'),
                                'type' => 'textarea'
                            ),
                            array(
                                'id' => "gf_format_gallery_images",
                                'title' => esc_html__('Featured Gallery','oars-framework'),
                                'subtitle' => esc_html__('Select images for featured gallery. (Apply for post format gallery)','oars-framework'),
                                'type' => 'gallery'
                            ),
                            array(
                                'id' => "gf_format_link_text",
                                'title' => esc_html__('Featured Link Text','oars-framework'),
                                'subtitle' => esc_html__('Enter featured link text. (Apply for post format link)','oars-framework'),
                                'type' => 'text'
                            ),
                            array(
                                'id' => "gf_format_link_url",
                                'title' => esc_html__('Featured Link URL','oars-framework'),
                                'subtitle' => esc_html__('Enter featured link url. (Apply for post format link)','oars-framework'),
                                'type' => 'text'
                            ),
                            array(
                                'id' => "gf_format_quote_content",
                                'title' => esc_html__('Featured Quote Content','oars-framework'),
                                'subtitle' => esc_html__('Enter featured quote content','oars-framework'),
                                'type' => 'textarea'
                            ),
                            array(
                                'id' => "gf_format_quote_author_text",
                                'title' => esc_html__('Featured Quote Author Name','oars-framework'),
                                'subtitle' => esc_html__('Enter featured quote author name','oars-framework'),
                                'type' => 'text'
                            ),
                            array(
                                'id' => "gf_format_quote_author_url",
                                'title' => esc_html__('Featured Quote Author URL','oars-framework'),
                                'subtitle' => esc_html__('Enter featured quote author url','oars-framework'),
                                'type' => 'text'
                            ),
							array(
								'id'       => "{$prefix}single_post_layout",
								'title'    => esc_html__('Post Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your post layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_single_post_layout(true),
								'default'  => '',
								'required' => array('single_post_layout', 'not in', array('layout-8', 'layout-9'))
							),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_feature_image_enable",
								'title'    => esc_html__('Feature Image', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide Feature Image area on single blog', 'achilles-framework'),
								'default'  => '',
								'required' => array('single_post_layout', 'not in', array('layout-7', 'layout-8'))
							), true),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_reading_process_enable",
								'title'    => esc_html__('Reading Process', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide reading process on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_tag_enable",
								'title'    => esc_html__('Tags', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide tags on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_share_enable",
								'title'    => esc_html__('Share', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide share on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_navigation_enable",
								'title'    => esc_html__('Navigation', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide navigation on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_author_info_enable",
								'title'    => esc_html__('Author Info', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide author info area on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							array(
								'id'       => "{$prefix}author_info_layout",
								'title'    => esc_html__('Author Info Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your author info layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_author_info_layout(),
								'default'  => 'author-layout-1',
								'required' => array('single_author_info_enable', '=', 'on')
							),
							array(
								'id'      => "{$prefix}single_post_ordinal",
								'title'   => esc_html__('Single Post Ordinal', 'achilles-framework'),
								'type'    => 'sortable',
								'options' => G5P()->settings()->get_single_post_ordinal(),
								'default' => array('related-post', 'content-block', 'comment'),
							),
							G5P()->configOptions()->get_config_content_block(array(
								'id'   => "{$prefix}single_post_content_block",
								'title'    => esc_html__('Content Block Single Post', 'achilles-framework'),
								'desc' => esc_html__('Specify the Content Block to use as a single post content.', 'achilles-framework'),
							), true),
							array(
								'id'       => "{$prefix}comment_layout",
								'title'    => esc_html__('Comment Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your comment layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_comment_layout(),
								'default'  => 'comment-layout-2',
							),
						)
					),
					array(
						'id'     => "{$prefix}section_post_related",
						'title'  => esc_html__('Related Posts', 'achilles-framework'),
						'icon'   => 'dashicons dashicons-images-alt2',
						'fields' => array(
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_related_post_enable",
								'title'    => esc_html__('Related Posts', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide related posts area on single blog', 'achilles-framework'),
								'default'  => ''
							), true),
							array(
								'id'       => "{$prefix}single_related_layout",
								'title'    => esc_html__('Related Posts Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your related posts layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_related_post_layout(),
								'default'  => 'related-post-layout-1',
								'required' => array('single_related_post_enable', '=', 'on')
							),
							array(
								'id'       => "{$prefix}single_related_post_algorithm",
								'title'    => esc_html__('Related Posts Algorithm', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the algorithm of related posts', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_related_post_algorithm(true),
								'default'  => '',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							),
							G5P()->configOptions()->get_config_toggle(array(
								'id'       => "{$prefix}single_related_post_carousel_enable",
								'title'    => esc_html__('Carousel Mode', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable carousel mode', 'achilles-framework'),
								'default'  => '',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							), true),
							array(
								'id'         => "{$prefix}single_related_post_per_page",
								'title'      => esc_html__('Posts Per Page', 'achilles-framework'),
								'subtitle'   => esc_html__('Enter number of posts per page you want to display', 'achilles-framework'),
								'type'       => 'text',
								'input_type' => 'number',
								'default'    => '',
								'required'   => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							),
							array(
								'id'       => "{$prefix}single_related_post_columns_gutter",
								'title'    => esc_html__('Post Columns Gutter', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your horizontal space between post.', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_post_columns_gutter(true),
								'default'  => '',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							),
							array(
								'id'       => "{$prefix}single_related_post_columns_group",
								'title'    => esc_html__('Post Columns', 'achilles-framework'),
								'type'     => 'group',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', '')),
								'fields'   => array(
									array(
										'id'     => "{$prefix}single_related_post_columns_row_1",
										'type'   => 'row',
										'col'    => 3,
										'fields' => array(
											array(
												'id'      => "{$prefix}single_related_post_columns",
												'title'   => esc_html__('Large Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on large devices (>= 1200px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(true),
												'default' => '',
												'layout'  => 'full',
											),
											array(
												'id'      => "{$prefix}single_related_post_columns_md",
												'title'   => esc_html__('Medium Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on medium devices (>= 992px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(true),
												'default' => '',
												'layout'  => 'full',
											),
											array(
												'id'      => "{$prefix}single_related_post_columns_sm",
												'title'   => esc_html__('Small Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on small devices (>= 768px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(true),
												'default' => '',
												'layout'  => 'full',
											),
											array(
												'id'      => "{$prefix}single_related_post_columns_xs",
												'title'   => esc_html__('Extra Small Devices ', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on extra small devices (< 768px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(true),
												'default' => '',
												'layout'  => 'full',
											),
											array(
												'id' => "{$prefix}single_related_post_columns_mb",
												'title' => esc_html__('Extra Extra Small Devices ', 'achilles-framework'),
												'desc' => esc_html__('Specify your post columns on extra extra small devices (< 468px)', 'achilles-framework'),
												'type' => 'select',
												'options' => G5P()->settings()->get_post_columns(true),
												'default' => '',
												'layout' => 'full',
											)
										)
									),
								)
							),
							array(
								'id'       => "{$prefix}single_related_post_paging",
								'title'    => esc_html__('Post Paging', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your post paging mode', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_post_paging_small_mode(true),
								'default'  => '',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							),
							array(
								'id'       => "{$prefix}single_related_post_animation",
								'title'    => esc_html__('Animation', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your post animation', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_animation(true),
								'default'  => '',
								'required' => array("{$prefix}single_related_post_enable", 'in', array('on', ''))
							)
						)
					),

                    array(
                        'id' =>  "{$prefix}section_layout",
                        'title' => esc_html__('Layout', 'achilles-framework'),
                        'icon' => 'dashicons dashicons-editor-table',
                        'fields' => array(
                            G5P()->configOptions()->get_config_preset(array('id' => "{$prefix}page_preset")),
                            array(
                                'id'     => "{$prefix}group_layout",
                                'type'   => 'group',
                                'title'  => esc_html__('Layout', 'achilles-framework'),
                                'fields' => array(
                                    array(
                                        'id'      => "{$prefix}main_layout",
                                        'title'   => esc_html__('Site Layout', 'achilles-framework'),
                                        'type'    => 'image_set',
                                        'options' => G5P()->settings()->get_main_layout(true),
                                        'default' => '',
                                    ),

                                    G5P()->configOptions()->get_config_toggle(array(
                                        'id'       => "{$prefix}content_full_width",
                                        'title'    => esc_html__('Content Full Width', 'achilles-framework'),
                                        'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width.', 'achilles-framework'),
                                        'default'  => '',
                                    ), true),

                                    G5P()->configOptions()->get_config_toggle(array(
                                        'id'       => "{$prefix}custom_content_padding",
                                        'title'    => esc_html__('Custom Content Padding', 'achilles-framework'),
                                        'subtitle' => esc_html__('Turn On this option if you want to custom content padding.', 'achilles-framework'),
                                        'default'  => ''
                                    )),

                                    array(
                                        'id'       => "{$prefix}content_padding",
                                        'title'    => esc_html__('Content Padding', 'achilles-framework'),
                                        'subtitle' => esc_html__('Set content padding', 'achilles-framework'),
                                        'type'     => 'spacing',
                                        'default'  => array('left' => 0, 'right' => 0, 'top' => 60, 'bottom' => 60),
                                        'required' => array("{$prefix}custom_content_padding", '=', 'on')
                                    ),

                                    G5P()->configOptions()->get_config_sidebar_layout(array(
                                        'id' => "{$prefix}sidebar_layout",
                                    ), true),
                                    G5P()->configOptions()->get_config_sidebar(array(
                                        'id'       => "{$prefix}sidebar",
                                        'required' => array("{$prefix}sidebar_layout", '!=', 'none')
                                    )),
                                )
                            ),

                            array(
                                'id'     => "{$prefix}group_page_title",
                                'type'   => 'group',
                                'title'  => esc_html__('Page Title', 'achilles-framework'),
                                'fields' => array(
                                    G5P()->configOptions()->get_config_toggle(array(
                                        'title' => esc_html__('Page Title Enable', 'achilles-framework'),
                                        'id'    => "{$prefix}page_title_enable"
                                    ), true),
                                    G5P()->configOptions()->get_config_content_block(array(
                                        'id'       => "{$prefix}page_title_content_block",
                                        'desc'     => esc_html__('Specify the Content Block to use as a page title content.', 'achilles-framework'),
                                        'required' => array("{$prefix}page_title_enable", '!=', 'off')
                                    ), true),

                                    array(
                                        'title'    => esc_html__('Custom Page title', 'achilles-framework'),
                                        'id'       => "{$prefix}page_title_content",
                                        'type'     => 'text',
                                        'default'  => '',
                                        'required' => array("{$prefix}page_title_enable", '!=', 'off'),
                                        'desc'     => esc_html__('Enter custom page title for this page', 'achilles-framework')
                                    )
                                )
                            ),
                            array(
                                'title'   => esc_html__('Custom Css Class', 'achilles-framework'),
                                'id'      => "{$prefix}css_class",
                                'type'    => 'selectize',
                                'tags'    => true,
                                'default' => '',
                                'desc'    => esc_html__('Enter custom class for this page', 'achilles-framework')
                            )
                        )
                    ),


                    array(
                        'id'     => "{$prefix}section_menu",
                        'title'  => esc_html__('Menu', 'achilles-framework'),
                        'icon'   => 'dashicons dashicons-menu',
                        'fields' => array(
                            array(
                                'id'          => "{$prefix}page_menu",
                                'title'       => esc_html__('Page Menu', 'achilles-framework'),
                                'type'        => 'selectize',
                                'allow_clear' => true,
                                'placeholder' => esc_html__('Select Menu', 'achilles-framework'),
                                'desc'        => esc_html__('Optionally you can choose to override the menu that is used on the page', 'achilles-framework'),
                                'data'        => 'menu'
                            ),
                            array(
                                'id'          => "{$prefix}page_mobile_menu",
                                'title'       => esc_html__('Page Mobile Menu', 'achilles-framework'),
                                'type'        => 'selectize',
                                'allow_clear' => true,
                                'placeholder' => esc_html__('Select Menu', 'achilles-framework'),
                                'desc'        => esc_html__('Optionally you can choose to override the menu mobile that is used on the page', 'achilles-framework'),
                                'data'        => 'menu'
                            ),
                            G5P()->configOptions()->get_config_toggle(array(
                                'id'    => "{$prefix}is_one_page",
                                'title' => esc_html__('Is One Page', 'achilles-framework'),
                                'desc'  => esc_html__('Set page style is One Page', 'achilles-framework'),
                            ))
                        )
                    ),

				)
			);
			
			
			return $configs;
		}
	}
}