<?php
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}

if (!class_exists('G5P_Inc_Config_Options')) {
	class G5P_Inc_Config_Options
	{
		/*
		 * loader instances
		 */
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		public function init()
		{
			// Defined Theme Options
			add_filter('gsf_option_config', array($this, 'define_theme_options'));
		}
		
		public function define_theme_options($configs)
		{
			$configs['gsf_skins'] = array(
				'layout'      => 'inline',
				'page_title'  => esc_html__('Achilles Skin Options', 'achilles-framework'),
				'menu_title'  => esc_html__('Skins Options', 'achilles-framework'),
				'option_name' => G5P()->getOptionSkinName(),
				'permission'  => 'manage_options',
				'parent_slug' => 'gsf_welcome',
				'fields'      => array(
					// Color Skin
					$this->get_config_section_color_skin(),
				),
			);
			
			$configs['gsf_options'] = array(
				'layout'      => 'inline',
				'page_title'  => esc_html__('Achilles Theme Options', 'achilles-framework'),
				'menu_title'  => esc_html__('Theme Options', 'achilles-framework'),
				'option_name' => G5P()->getOptionName(),
				'permission'  => 'manage_options',
				'parent_slug' => 'gsf_welcome',
				'preset'      => true,
				'section'     => array(
					
					// General
					$this->get_config_section_general(),
					
					
					// Layout
					$this->get_config_section_layout(),
					
					// Top Drawer
					$this->get_config_section_top_drawer(),
					
					// Top Bar
					$this->get_config_section_top_bar(),
					
					// Header
					$this->get_config_section_header(),
					
					// Logo
					$this->get_config_section_logo(),
					
					// Page Title
					$this->get_config_section_page_title(),
					
					// Footer
					$this->get_config_section_footer(),
					
					// Typography
					$this->get_config_section_typography(),
					
					
					// Color
					$this->get_config_section_colors(),
					
					// Connections
					$this->get_config_section_connections(),
					
					// Blog
					$this->get_config_section_blog(),
					
					// Preset
					$this->get_config_section_preset(),
					
					//popup
					$this->get_config_section_popup(),
					
					// Custom css & js
					$this->get_config_section_code(),
				
				
				),
			);
			
			return $configs;
		}
		
		/**
		 * Get Config General
		 *
		 * @return array
		 */
		public function get_config_section_general()
		{
			return array(
				'id'              => 'section_general',
				'title'           => esc_html__('General', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-admin-site',
				'general_options' => true,
				'fields'          => array(
					/**
					 * General
					 */
					array(
						'id'     => 'section_general_group_general',
						'title'  => esc_html__('General', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'smooth_scroll',
								'title'    => esc_html__('Smooth Scroll', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable smooth scroll', 'achilles-framework'),
								'default'  => ''
							)),
							$this->get_config_toggle(array(
								'id'       => 'lazy_load_images',
								'title'    => esc_html__('Lazy Load Images', 'achilles-framework'),
								'subtitle' => esc_html__('If enabled, images will only be loaded when they come to view', 'achilles-framework'),
								'default'  => ''
							)),
							
							array(
								'id'     => 'section_general_group_custom_scroll',
								'title'  => esc_html__('Custom Scroll', 'achilles-framework'),
								'type'   => 'group',
								'fields' => array(
									$this->get_config_toggle(array(
										'id'       => 'custom_scroll',
										'title'    => esc_html__('Custom Scroll', 'achilles-framework'),
										'subtitle' => esc_html__('Turn On this option if you want to custom scroll', 'achilles-framework'),
										'default'  => ''
									)),
									array(
										'id'         => 'custom_scroll_width',
										'type'       => 'text',
										'input_type' => 'number',
										'title'      => esc_html__('Custom Scroll Width', 'achilles-framework'),
										'subtitle'   => esc_html__('This must be numeric (no px) or empty.', 'achilles-framework'),
										'default'    => 10,
										'required'   => array('custom_scroll', '=', 'on'),
									),
									array(
										'id'       => 'custom_scroll_color',
										'type'     => 'color',
										'title'    => esc_html__('Custom Scroll Color', 'achilles-framework'),
										'default'  => '#19394B',
										'required' => array('custom_scroll', '=', 'on'),
									),
									array(
										'id'       => 'custom_scroll_thumb_color',
										'type'     => 'color',
										'title'    => esc_html__('Custom Scroll Thumb Color', 'achilles-framework'),
										'default'  => '#69d2e7',
										'required' => array('custom_scroll', '=', 'on'),
									),
								)
							),
							$this->get_config_toggle(array(
								'id'       => 'back_to_top',
								'title'    => esc_html__('Back To Top', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to disable back to top', 'achilles-framework'),
								'default'  => 'on'
							)),
							
							$this->get_config_toggle(array(
								'id'       => 'rtl_enable',
								'title'    => esc_html__('RTL Mode', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable rtl mode', 'achilles-framework'),
								'default'  => ''
							)),
							array(
								'id'              => 'menu_transition',
								'type'            => 'select',
								'title'           => esc_html__('Menu Transition', 'achilles-framework'),
								'default'         => 'x-fadeInUp',
								'general_options' => true,
								'options'         => array(
									'none'          => esc_html__('None', 'achilles-framework'),
									'x-fadeIn'      => esc_html__('Fade In', 'achilles-framework'),
									'x-fadeInUp'    => esc_html__('Fade In Up', 'achilles-framework'),
									'x-fadeInDown'  => esc_html__('Fade In Down', 'achilles-framework'),
									'x-fadeInLeft'  => esc_html__('Fade In Left', 'achilles-framework'),
									'x-fadeInRight' => esc_html__('Fade In Right', 'achilles-framework'),
									'x-flipInX'     => esc_html__('Flip In X', 'achilles-framework'),
									'x-slideInUp'   => esc_html__('Slide In Up', 'achilles-framework')
								)
							),
							
							array(
								'id'     => 'section_general_group_social_meta',
								'title'  => esc_html__('Social Meta', 'achilles-framework'),
								'type'   => 'group',
								'fields' => array(
									
									$this->get_config_toggle(array(
										'id'       => 'social_meta_enable',
										'title'    => esc_html__('Enable Social Meta Tags', 'achilles-framework'),
										'subtitle' => esc_html__('Turn On this option if you want to enable social meta', 'achilles-framework'),
										'default'  => ''
									)),
									array(
										'id'       => 'twitter_author_username',
										'type'     => 'text',
										'title'    => esc_html__('Twitter Username', 'achilles-framework'),
										'subtitle' => esc_html__('Enter your twitter username here, to be used for the Twitter Card date. Ensure that you do not include the @ symbol.', 'achilles-framework'),
										'default'  => '',
										'required' => array('social_meta_enable', '=', 'on'),
									),
									array(
										'id'       => 'googleplus_author',
										'type'     => 'text',
										'title'    => esc_html__('Google+ Username', 'achilles-framework'),
										'subtitle' => esc_html__('Enter your Google+ username here, to be used for the authorship meta.', 'achilles-framework'),
										'default'  => '',
										'required' => array('social_meta_enable', '=', 'on'),
									),
								)
							),
							
							array(
								'id'     => 'section_general_group_search_popup',
								'title'  => esc_html__('Search Popup', 'achilles-framework'),
								'type'   => 'group',
								'fields' => array(
									array(
										'id'       => 'search_popup_post_type',
										'type'     => 'checkbox_list',
										'title'    => esc_html__('Post Type For Ajax Search', 'achilles-framework'),
										'options'  => G5P()->settings()->get_search_ajax_popup_post_type(),
										'multiple' => true,
										'default'  => array('post', 'product'),
									),
									array(
										'id'         => 'search_popup_result_amount',
										'type'       => 'text',
										'input_type' => 'number',
										'title'      => esc_html__('Amount Of Search Result', 'achilles-framework'),
										'default'    => 8,
									),
								
								)
							),
						)
					),
					/**
					 * Maintenance
					 */
					array(
						'id'             => 'section_general_group_maintenance',
						'title'          => esc_html__('Maintenance', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							array(
								'id'      => 'maintenance_mode',
								'type'    => 'button_set',
								'title'   => esc_html__('Maintenance Mode', 'achilles-framework'),
								'options' => G5P()->settings()->get_maintenance_mode(),
								'default' => '0'
							),
							array(
								'id'          => 'maintenance_mode_page',
								'title'       => esc_html__('Maintenance Mode Page', 'achilles-framework'),
								'subtitle'    => esc_html__('Select the page that is your maintenance page, if you would like to show a custom page instead of the standard WordPress message. You should use the Holding Page template for this page.', 'achilles-framework'),
								'type'        => 'selectize',
								'placeholder' => esc_html__('Select Page', 'achilles-framework'),
								'data'        => 'page',
								'data_args'   => array(
									'numberposts' => -1
								),
								'edit_link'   => true,
								'default'     => '',
								'required'    => array('maintenance_mode', '=', '2'),
							
							),
						)
					),
					/**
					 * Page Transition Section
					 * *******************************************************
					 */
					array(
						'id'             => 'section_general_group_page_transition',
						'title'          => esc_html__('Page Transition', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							$this->get_config_toggle(array(
								'id'       => 'page_transition',
								'title'    => esc_html__('Page Transition', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable page transition', 'achilles-framework'),
								'default'  => ''
							)),
							array(
								'id'       => 'loading_animation',
								'type'     => 'select',
								'title'    => esc_html__('Loading Animation', 'achilles-framework'),
								'subtitle' => esc_html__('Select type of pre load animation', 'achilles-framework'),
								'options'  => G5P()->settings()->get_loading_animation(),
								'default'  => ''
							),
							array(
								'id'       => 'loading_logo',
								'type'     => 'image',
								'title'    => esc_html__('Logo Loading', 'achilles-framework'),
								'required' => array('loading_animation', '!=', ''),
							),
							
							array(
								'id'       => 'loading_animation_bg_color',
								'title'    => esc_html__('Loading Background Color', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => '#fff',
								'required' => array('loading_animation', '!=', ''),
							),
							
							array(
								'id'       => 'spinner_color',
								'title'    => esc_html__('Spinner color', 'achilles-framework'),
								'type'     => 'color',
								'default'  => '',
								'required' => array('loading_animation', '!=', ''),
							),
						
						)
					),
					/**
					 * Custom Favicon
					 * *******************************************************
					 */
					array(
						'id'             => 'section_general_group_custom_favicon',
						'title'          => esc_html__('Custom Favicon', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							array(
								'id'       => 'custom_favicon',
								'type'     => 'image',
								'title'    => esc_html__('Custom favicon', 'achilles-framework'),
								'subtitle' => esc_html__('Upload a 16px x 16px Png/Gif/ico image that will represent your website favicon', 'achilles-framework'),
							),
							array(
								'id'       => 'custom_ios_title',
								'type'     => 'text',
								'title'    => esc_html__('Custom iOS Bookmark Title', 'achilles-framework'),
								'subtitle' => esc_html__('Enter a custom title for your site for when it is added as an iOS bookmark.', 'achilles-framework'),
								'default'  => ''
							),
							array(
								'id'       => 'custom_ios_icon57',
								'type'     => 'image',
								'title'    => esc_html__('Custom iOS 57x57', 'achilles-framework'),
								'subtitle' => esc_html__('Upload a 57px x 57px Png image that will be your website bookmark on non-retina iOS devices.', 'achilles-framework'),
							),
							array(
								'id'       => 'custom_ios_icon72',
								'type'     => 'image',
								'title'    => esc_html__('Custom iOS 72x72', 'achilles-framework'),
								'subtitle' => esc_html__('Upload a 72px x 72px Png image that will be your website bookmark on non-retina iOS devices.', 'achilles-framework'),
							),
							array(
								'id'       => 'custom_ios_icon114',
								'type'     => 'image',
								'title'    => esc_html__('Custom iOS 114x114', 'achilles-framework'),
								'subtitle' => esc_html__('Upload a 114px x 114px Png image that will be your website bookmark on retina iOS devices.', 'achilles-framework'),
							),
							array(
								'id'       => 'custom_ios_icon144',
								'type'     => 'image',
								'title'    => esc_html__('Custom iOS 144x144', 'achilles-framework'),
								'subtitle' => esc_html__('Upload a 144px x 144px Png image that will be your website bookmark on retina iOS devices.', 'achilles-framework'),
							),
						)
					),
					/**
					 * 404 Setting Section
					 * *******************************************************
					 */
					array(
						'id'             => 'section_general_group_404',
						'title'          => esc_html__('404 Page', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							$this->get_config_content_block(array(
								'id'       => '404_content_block',
								'subtitle' => esc_html__('Specify the Content Block to use as a 404 page content.', 'achilles-framework'),
								'required' => array('404_content_block_enable', '=', '1')
							)),
							array(
								'id'       => '404_content',
								'title'    => esc_html__('404 Page Content', 'achilles-framework'),
								'default'  => '',
								'type'     => 'editor',
								'required' => array('404_content_block', '=', '')
							)
						)
					),
				)
			);
		}
		
		public function get_config_section_preset()
		{
			
			$configs = G5P()->settings()->getPresetPostType();
			$fields = array();
			foreach ($configs as $key => $config) {
				if (isset($config['preset']) && is_array($config['preset'])) {
					$group_fields = array();
					foreach ($config['preset'] as $presetKey => $presetValue) {
						$group_fields[] = $this->get_config_preset(array(
							'id'          => "preset_{$presetKey}",
							'title'       => $presetValue['title'],
							'create_link' => false,
							'link_target' => false,
						));
					}
					$group = array(
						'type'   => 'group',
						'title'  => $config['title'],
						'fields' => $group_fields
					);
					$fields[] = $group;
				} else {
					$fields[] = $this->get_config_preset(array(
						'id'          => "preset_{$key}",
						'title'       => $config['title'],
						'create_link' => false,
						'link_target' => false,
					));
				}
			}
			
			return array(
				'id'              => 'section_preset',
				'title'           => esc_html__('Preset Setting', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-admin-generic',
				'general_options' => true,
				'fields'          => $fields
			);
		}
		
		/**
		 * Get Config Layout
		 *
		 * @return array
		 */
		public function get_config_section_layout()
		{
			return array(
				'id'     => 'section_layout',
				'title'  => esc_html__('Layout', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-editor-table',
				'fields' => array(
					array(
						'id'      => 'main_layout',
						'title'   => esc_html__('Site Layout', 'achilles-framework'),
						'type'    => 'image_set',
						'options' => G5P()->settings()->get_main_layout(),
						'default' => 'wide',
					),
					
					
					array(
						'id'     => 'section_layout_group_main_content',
						'title'  => esc_html__('Main Content', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'content_full_width',
								'title'    => esc_html__('Content Full Width', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width.', 'achilles-framework'),
								'default'  => '',
							)),
							array(
								'id'       => 'content_padding',
								'title'    => esc_html__('Content Padding', 'achilles-framework'),
								'subtitle' => esc_html__('Set content padding', 'achilles-framework'),
								'type'     => 'spacing',
								'default'  => array('left' => 0, 'right' => 0, 'top' => 60, 'bottom' => 60),
							),
							$this->get_config_sidebar_layout(array('id' => 'sidebar_layout')),
							$this->get_config_sidebar(array(
								'id'       => 'sidebar',
								'default'  => 'main',
								'required' => array('sidebar_layout', '!=', 'none')
							)),
							array(
								'id'       => 'sidebar_width',
								'title'    => esc_html__('Sidebar Width', 'achilles-framework'),
								'type'     => 'button_set',
								'options'  => G5P()->settings()->get_sidebar_width(),
								'default'  => 'small',
								'required' => array('sidebar_layout', '!=', 'none'),
							),
							$this->get_config_toggle(array(
								'id'       => 'sidebar_sticky_enable',
								'title'    => esc_html__('Sidebar Sticky', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable sidebar sticky', 'achilles-framework'),
								'default'  => '',
								'required' => array('sidebar_layout', '!=', 'none'),
							))
						
						)
					),
					
					array(
						'id'     => 'section_layout_group_mobile',
						'title'  => esc_html__('Mobile', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'mobile_sidebar_enable',
								'title'    => esc_html__('Sidebar Mobile', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to disable sidebar on mobile', 'achilles-framework'),
								'default'  => 'on',
								'required' => array('sidebar_layout', '!=', 'none'),
							)),
							$this->get_config_toggle(array(
								'id'       => 'mobile_sidebar_canvas',
								'title'    => esc_html__('Sidebar Mobile Canvas', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to disable canvas sidebar on mobile', 'achilles-framework'),
								'default'  => 'on',
								'required' => array(
									array('sidebar_layout', '!=', 'none'),
									array('mobile_sidebar_enable', '=', 'on'),
								)
							)),
							array(
								'id'       => 'mobile_content_padding',
								'title'    => esc_html__('Content Padding Mobile', 'achilles-framework'),
								'subtitle' => esc_html__('Set content top/bottom padding', 'achilles-framework'),
								'type'     => 'spacing'
							),
						)
					),
				)
			);
		}
		
		/**
		 * Get Config Top Drawer
		 *
		 * @return array
		 */
		public function get_config_section_top_drawer()
		{
			return array(
				'id'     => 'section_top_drawer',
				'title'  => esc_html__('Top Drawer', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-archive',
				'fields' => array(
					array(
						'id'      => 'top_drawer_mode',
						'title'   => esc_html__('Top Drawer Mode', 'achilles-framework'),
						'type'    => 'button_set',
						'options' => G5P()->settings()->get_top_drawer_mode(),
						'default' => 'hide'
					),
					$this->get_config_content_block(array(
						'id'       => 'top_drawer_content_block',
						'subtitle' => esc_html__('Specify the Content Block to use as a top drawer content.', 'achilles-framework'),
						'required' => array('top_drawer_mode', '!=', 'hide')
					)),
					$this->get_config_toggle(array(
						'id'       => 'top_drawer_content_full_width',
						'title'    => esc_html__('Top Drawer Full Width', 'achilles-framework'),
						'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width.', 'achilles-framework'),
						'default'  => '',
						'required' => array('top_drawer_mode', '!=', 'hide')
					)),
					array(
						'id'       => "top_drawer_padding",
						'title'    => esc_html__('Padding', 'achilles-framework'),
						'subtitle' => esc_html__('Set top drawer padding', 'achilles-framework'),
						'type'     => 'spacing',
						'default'  => array(
							'top'    => 10,
							'bottom' => 10
						),
						'required' => array('top_drawer_mode', '!=', 'hide')
					),
					$this->get_config_border_bottom('top_drawer_border', array(
						'required' => array('top_drawer_mode', '!=', 'hide')
					)),
					$this->get_config_toggle(array(
						'id'       => 'mobile_top_drawer_enable',
						'title'    => esc_html__('Mobile Enable', 'achilles-framework'),
						'subtitle' => esc_html__('Turn On this option if you want to enable top drawer on mobile', 'achilles-framework'),
						'default'  => '',
						'required' => array('top_drawer_mode', '!=', 'hide')
					)),
				)
			);
		}
		
		/**
		 * Get Config Top Bar
		 *
		 * @return array
		 */
		public function get_config_section_top_bar()
		{
			return array(
				'id'     => 'section_top_bar',
				'title'  => esc_html__('Top Bar', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-schedule',
				'fields' => array(
					array(
						'id'     => 'section_top_bar_group_desktop',
						'title'  => esc_html__('Desktop', 'achilles-framework'),
						'type'   => 'group',
						'required' => array('header_layout', 'not in', array('header-6', 'header-7')),
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'top_bar_enable',
								'title'    => esc_html__('Top Bar Enable', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable top bar', 'achilles-framework'),
								'default'  => ''
							)),
							$this->get_config_content_block(array(
								'id'       => 'top_bar_content_block',
								'subtitle' => esc_html__('Specify the Content Block to use as a top bar content.', 'achilles-framework'),
								'required' => array('top_bar_enable', '=', 'on')
							)),
						)),
					
					array(
						'id'     => 'section_top_bar_group_mobile',
						'title'  => esc_html__('Mobile', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'mobile_top_bar_enable',
								'title'    => esc_html__('Top Bar Enable', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable top bar', 'achilles-framework'),
								'default'  => ''
							)),
							$this->get_config_content_block(array(
								'id'       => 'mobile_top_bar_content_block',
								'subtitle' => esc_html__('Specify the Content Block to use as a top bar content.', 'achilles-framework'),
								'required' => array('mobile_top_bar_enable', '=', 'on')
							)),
						)),
				)
			);
		}
		
		/**
		 * Get Config Header
		 *
		 * @return array
		 */
		public function get_config_section_header()
		{
			return array(
				'id'     => 'section_header',
				'title'  => esc_html__('Header', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-editor-kitchensink',
				'fields' => array(
					G5P()->configOptions()->get_config_toggle(array(
						'id'       => 'header_enable',
						'title'    => esc_html__('Header Enable', 'achilles-framework'),
						'default'  => 'on',
						'subtitle' => esc_html__('Turn Off this option if you want to hide header', 'achilles-framework'),
					)),
					array(
						'id'       => 'header_responsive_breakpoint',
						'type'     => 'select',
						'title'    => esc_html__('Header Responsive Breakpoint', 'achilles-framework'),
						'options'  => array(
							'1199' => esc_html__('Large Devices: < 1200px', 'achilles-framework'),
							'991'  => esc_html__('Medium Devices: < 992px', 'achilles-framework'),
							'767'  => esc_html__('Tablet Portrait: < 768px', 'achilles-framework'),
						),
						'default'  => '1199',
						'required' => array('header_enable', '=', 'on')
					),
					array(
						'id'       => 'section_header_group_header_desktop',
						'title'    => esc_html__('Desktop', 'achilles-framework'),
						'type'     => 'group',
						'required' => array('header_enable', '=', 'on'),
						'fields'   => array(
							array(
								'id'      => 'header_layout',
								'title'   => esc_html__('Header Layout', 'achilles-framework'),
								'type'    => 'image_set',
								'options' => G5P()->settings()->get_header_layout(),
								'default' => 'header-2',
							),
							$this->get_config_group_header_customize('section_header_group_customize_left', esc_html__('Customize Left', 'achilles-framework'), 'header_customize_left', array(), array('header_layout', 'in', G5P()->settings()->get_header_customize_left_required())),
							$this->get_config_group_header_customize('section_header_group_customize_right', esc_html__('Customize Right', 'achilles-framework'), 'header_customize_right', array(), array('header_layout', 'in', G5P()->settings()->get_header_customize_right_required())),
							$this->get_config_group_header_customize('section_header_group_customize_nav_left', esc_html__('Customize Navigation Left', 'achilles-framework'), 'header_customize_nav_left', array(), array('header_layout', 'in', G5P()->settings()->get_header_customize_nav_left_required())),
							$this->get_config_group_header_customize('section_header_group_customize_nav_right', esc_html__('Customize Navigation Right', 'achilles-framework'), 'header_customize_nav_right', array(), array('header_layout', 'in', G5P()->settings()->get_header_customize_nav_right_required())),
							$this->get_config_toggle(array(
								'id'       => 'header_above_full_width',
								'title'    => esc_html__('Header Above Full Width', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width', 'achilles-framework'),
								'default'  => '',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							)),
							$this->get_config_toggle(array(
								'id'       => 'header_navigation_full_width',
								'title'    => esc_html__('Header Navigation Full Width', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to expand the content area to full width', 'achilles-framework'),
								'default'  => '',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							)),
							$this->get_config_toggle(array(
								'id'       => 'header_float_enable',
								'title'    => esc_html__('Header Float', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable header float', 'achilles-framework'),
								'default'  => '',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							)),
							$this->get_config_toggle(array(
								'id'       => 'header_sticky_enable',
								'title'    => esc_html__('Header Sticky', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable header sticky', 'achilles-framework'),
								'default'  => 'on',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							)),
							$this->get_config_border_bottom('header_border', array(
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							)),
							$this->get_config_border_bottom('header_above_border', array(
								'title'   => esc_html__('Header Above Border Bottom', 'achilles-framework'),
								'default' => 'full',
								'required' => array('header_layout', 'in', array('header-1','header-2', 'header-6', 'header-7'))
							)),
							array(
								'id'       => 'header_padding',
								'type'     => 'spacing',
								'title'    => esc_html__('Header Padding', 'achilles-framework'),
								'subtitle' => esc_html__('If you would like to override the default header padding, then you can do so here.', 'achilles-framework'),
								'required' => array('header_layout', 'not in', array('header-6', 'header-7'))
							),
							
							array(
								'id'     => 'section_header_group_navigation',
								'title'  => esc_html__('Navigation', 'achilles-framework'),
								'type'   => 'group',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7')),
								'fields' => array(
									array(
										'id'       => 'navigation_height',
										'type'     => 'dimension',
										'title'    => esc_html__('Navigation Height', 'achilles-framework'),
										'subtitle' => esc_html__('If you would like to override the default navigation height, then you can do so here.', 'achilles-framework'),
										'width'    => false,
										'default'  => '55',
										'required' => array('header_layout', 'not in', array('header-3', 'header-4', 'header-7'))
									),
									$this->get_config_spacing('navigation_spacing', array(
										'title' => esc_html__('Navigation Spacing', 'achilles-framework')
									))
								)
							)
						)
					),
					
					array(
						'id'       => 'section_header_group_header_mobile',
						'title'    => esc_html__('Mobile', 'achilles-framework'),
						'type'     => 'group',
						'required' => array('header_enable', '=', 'on'),
						'fields'   => array(
							array(
								'id'      => 'mobile_header_layout',
								'title'   => esc_html__('Header Layout', 'achilles-framework'),
								'type'    => 'image_set',
								'options' => G5P()->settings()->get_header_mobile_layout(),
								'default' => 'header-1'
							),
							$this->get_config_toggle(array(
								'id'       => 'mobile_header_search_enable',
								'title'    => esc_html__('Search Box', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable search box', 'achilles-framework'),
								'default'  => '',
							)),
							$this->get_config_toggle(array(
								'id'       => 'mobile_header_sticky_enable',
								'title'    => esc_html__('Header Sticky', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable header sticky', 'achilles-framework'),
								'default'  => '',
							)),
							$this->get_config_group_header_customize('section_mobile_header_group_customize', esc_html__('Customize', 'achilles-framework'), 'header_customize_mobile', array('search')),
							$this->get_config_border_bottom('mobile_header_border'),
							array(
								'id'       => 'mobile_header_padding',
								'type'     => 'spacing',
								'title'    => esc_html__('Header Padding', 'achilles-framework'),
								'left'     => false,
								'right'    => false,
								'subtitle' => esc_html__('If you would like to override the default header padding, then you can do so here.', 'achilles-framework'),
							),
						)
					)
				
				)
			);
		}
		
		/**
		 * Get Config Logo
		 *
		 * @return array
		 */
		public function get_config_section_logo()
		{
			return array(
				'id'     => 'section_logo',
				'title'  => esc_html__('Logo', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-image-filter',
				'fields' => array(
					array(
						'id'     => 'section_logo_group_desktop',
						'title'  => esc_html__('Desktop', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'       => 'logo',
								'title'    => esc_html__('Logo', 'achilles-framework'),
								'subtitle' => esc_html__('By default, a text-based logo is created using your site title. But you can also upload an image-based logo here.', 'achilles-framework'),
								'type'     => 'image',
							),
							array(
								'id'       => 'logo_retina',
								'title'    => esc_html__('Logo Retina (2x)', 'achilles-framework'),
								'subtitle' => esc_html__('If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo.', 'achilles-framework'),
								'type'     => 'image',
								'default'  => ''
							),
							array(
								'id'       => 'sticky_logo',
								'title'    => esc_html__('Sticky Logo', 'achilles-framework'),
								'type'     => 'image',
								'required' => array('header_sticky_enable', '=', 'on')
							),
							array(
								'id'       => 'sticky_logo_retina',
								'title'    => esc_html__('Sticky Logo Retina', 'achilles-framework'),
								'subtitle' => esc_html__('If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo.', 'achilles-framework'),
								'type'     => 'image',
								'default'  => '',
								'required' => array('header_sticky_enable', '=', 'on')
							),
							array(
								'id'       => 'logo_max_height',
								'title'    => esc_html__('Logo Max Height', 'achilles-framework'),
								'subtitle' => esc_html__('If you would like to override the default logo max height, then you can do so here.', 'achilles-framework'),
								'type'     => 'dimension',
								'width'    => false,
								'default'  => '130',
							),
							array(
								'id'       => 'logo_padding',
								'title'    => esc_html__('Logo Padding', 'achilles-framework'),
								'subtitle' => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'achilles-framework'),
								'type'     => 'spacing',
								'left'     => false,
								'right'    => false,
							)
						)
					),
					array(
						'id'     => 'section_logo_group_mobile',
						'title'  => esc_html__('Mobile', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'       => 'mobile_logo',
								'title'    => esc_html__('Logo', 'achilles-framework'),
								'subtitle' => esc_html__('By default, a text-based logo is created using your site title. But you can also upload an image-based logo here.', 'achilles-framework'),
								'type'     => 'image',
							),
							array(
								'id'       => 'mobile_logo_retina',
								'title'    => esc_html__('Logo Retina (2x)', 'achilles-framework'),
								'subtitle' => esc_html__('If you want to upload a Retina Image, It\'s Image Size should be exactly double in compare with your normal Logo.', 'achilles-framework'),
								'type'     => 'image',
								'default'  => ''
							),
							array(
								'id'       => 'mobile_logo_max_height',
								'title'    => esc_html__('Logo Max Height', 'achilles-framework'),
								'subtitle' => esc_html__('If you would like to override the default logo max height, then you can do so here.', 'achilles-framework'),
								'type'     => 'dimension',
								'width'    => false
							),
							array(
								'id'       => 'mobile_logo_padding',
								'title'    => esc_html__('Logo Padding', 'achilles-framework'),
								'subtitle' => esc_html__('If you would like to override the default logo top/bottom padding, then you can do so here.', 'achilles-framework'),
								'type'     => 'spacing',
								'left'     => false,
								'right'    => false,
							)
						)
					),
				)
			);
		}
		
		/**
		 * Get Config Page Title
		 *
		 * @return array
		 */
		public function get_config_section_page_title()
		{
			return array(
				'id'     => 'section_page_title',
				'title'  => esc_html__('Page Title', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-media-spreadsheet',
				'fields' => array(
					$this->get_config_toggle(array(
						'id'       => 'page_title_enable',
						'title'    => esc_html__('Page Title Enable', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Of this option if you want to disable page title', 'achilles-framework'),
						'default'  => 'on',
					)),
					$this->get_config_content_block(array(
						'id'       => 'page_title_content_block',
						'subtitle' => esc_html__('Specify the Content Block to use as a page title content.', 'achilles-framework'),
						'required' => array('page_title_enable', '=', 'on')
					))
				)
			);
		}
		
		/**
		 * Get Config Footer
		 *
		 * @return array
		 */
		public function get_config_section_footer()
		{
			return array(
				'id'     => 'section_footer',
				'title'  => esc_html__('Footer', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-feedback',
				'fields' => array(
					$this->get_config_toggle(array(
						'id' => 'footer_enable',
						'title' => esc_html__('Footer Enable', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to disable footer', 'achilles-framework'),
						'default' => 'on'
					)),
                    $this->get_config_content_block(array(
                        'id' => 'footer_content_block',
                        'subtitle' => esc_html__('Specify the Content Block to use as a footer content.', 'achilles-framework'),
                        'required' => array('footer_enable', '=', 'on')
                    )),
                    $this->get_config_toggle(array(
                        'id' => 'footer_fixed_enable',
                        'title' => esc_html__('Footer Fixed', 'achilles-framework'),
                        'default' => '',
                        'required' => array('footer_enable', '=', 'on'),
                    )),
				)
			);
		}
		
		/**
		 * Get Config Typography
		 *
		 * @return array
		 */
		public function get_config_section_typography()
		{
			return array(
				'id'              => 'section_typography',
				'title'           => esc_html__('Typography', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-editor-textcolor',
				'general_options' => true,
				'fields'          => array(
					array(
						'id'     => 'section_typography_group_general',
						'title'  => esc_html__('General', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'            => 'body_font',
								'title'         => esc_html__('Body Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the body font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Josefin Sans",
									'font_size'   => '18px',
									'font_weight' => '400'
								)
							),
							array(
								'id'       => 'primary_font',
								'title'    => esc_html__('Primary Font', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the primary font family.', 'achilles-framework'),
								'type'     => 'typography',
								'default'  => array(
									'font_family' => "Felix Titling",
								)
							),
						)
					),
					array(
						'id'     => 'section_typography_group_menu',
						'title'  => esc_html__('Menu', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'            => 'menu_font',
								'title'         => esc_html__('Menu Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the menu font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '14px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'sub_menu_font',
								'title'         => esc_html__('Sub Menu Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the sub menu font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '14px',
									'font_weight' => '700'
								)
							)
						)
					),
					array(
						'id'     => 'section_typography_group_headings',
						'title'  => esc_html__('Headings', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'       => 'heading_font',
								'title'    => esc_html__('Heading Font', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the heading font.', 'achilles-framework'),
								'type'     => 'typography',
								'default'  => array(
									'font_family' => "Oswald",
								)
							),
							array(
								'id'            => 'h1_font',
								'title'         => esc_html__('H1 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h1 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '36px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'h2_font',
								'title'         => esc_html__('H2 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h2 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '30px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'h3_font',
								'title'         => esc_html__('H3 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h3 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '24px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'h4_font',
								'title'         => esc_html__('H4 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h4 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '20px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'h5_font',
								'title'         => esc_html__('H5 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h5 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '16px',
									'font_weight' => '700'
								)
							),
							array(
								'id'            => 'h6_font',
								'title'         => esc_html__('H6 Font', 'achilles-framework'),
								'subtitle'      => esc_html__('Specify the h6 font.', 'achilles-framework'),
								'type'          => 'typography',
								'font_size'     => true,
								'font_variants' => true,
								'default'       => array(
									'font_family' => "Oswald",
									'font_size'   => '14px',
									'font_weight' => '700'
								)
							),
						)
					),
				)
			);
		}
		
		/**
		 * Get Config Color Skin
		 *
		 * @return array
		 */
		public function get_config_section_color_skin()
		{
			return array(
				'id'             => 'color_skin',
				'title'          => esc_html__('Skin', 'achilles-framework'),
				'desc'           => esc_html__('Define here all the color skin you will need.', 'achilles-framework'),
				'type'           => 'panel',
				'sort'           => true,
				'toggle_default' => false,
				'default'        => G5P()->settings()->get_color_skin_default(),
				'panel_title'    => 'skin_name',
				'fields'         => array(
					array(
						'id'       => 'skin_name',
						'title'    => esc_html__('Title', 'achilles-framework'),
						'subtitle' => esc_html__('Enter your color skin name', 'achilles-framework'),
						'type'     => 'text',
					),
					array(
						'id'         => 'skin_id',
						'title'      => esc_html__('Unique Skin Id', 'achilles-framework'),
						'subtitle'   => esc_html__('This value is created automatically and it shouldn\'t be edited unless you know what you are doing.', 'achilles-framework'),
						'type'       => 'text',
						'input_type' => 'unique_id',
						'default'    => 'skin-'
					),
					array(
						'id'     => 'section_color_skin_row_color_1',
						'type'   => 'row',
						'col'    => 4,
						'fields' => array(
							array(
								'id'      => 'background_color',
								'title'   => esc_html__('Background Color', 'achilles-framework'),
								'desc'    => esc_html__('Specify the background color', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#fff',
								'layout'  => 'full',
							),
							array(
								'id'      => 'text_color',
								'title'   => esc_html__('Text Color', 'achilles-framework'),
								'desc'    => esc_html__('Specify the text color', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#555',
								'layout'  => 'full',
							),
							array(
								'id'      => 'text_color_hover',
								'title'   => esc_html__('Text Color Hover', 'achilles-framework'),
								'desc'    => esc_html__('Specify the text color hover', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#e1757d',
								'layout'  => 'full',
							)
						)
					),
					array(
						'id'     => 'section_color_skin_row_color_2',
						'type'   => 'row',
						'col'    => 4,
						'fields' => array(
							array(
								'id'      => 'heading_color',
								'title'   => esc_html__('Heading Color', 'achilles-framework'),
								'desc'    => esc_html__('Specify the heading color', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#252525',
								'layout'  => 'full',
							),
							
							array(
								'id'      => 'disable_color',
								'title'   => esc_html__('Disable Color', 'achilles-framework'),
								'desc'    => esc_html__('Specify the disable color', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#acacac',
								'layout'  => 'full',
							),
							array(
								'id'      => 'border_color',
								'title'   => esc_html__('Border Color', 'achilles-framework'),
								'desc'    => esc_html__('Specify the border color', 'achilles-framework'),
								'type'    => 'color',
								'alpha'   => true,
								'default' => '#ebebeb',
								'layout'  => 'full',
							),
						)
					),
				),
			);
		}
		
		/**
		 * Get Config Color
		 *
		 * @return array
		 */
		public function get_config_section_colors()
		{
			return array(
				'id'     => 'section_colors',
				'title'  => esc_html__('Colors', 'achilles-framework'),
				'icon'   => 'dashicons dashicons-admin-customizer',
				'fields' => array(
					array(
						'id'     => 'section_color_group_general',
						'title'  => esc_html__('General', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'       => 'body_background',
								'title'    => esc_html__('Body Background', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the body background color and media.', 'achilles-framework'),
								'type'     => 'background',
							),
							array(
								'id'       => 'accent_color',
								'title'    => esc_html__('Accent Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the accent color', 'achilles-framework'),
								'type'     => 'color',
								'default'  => '#e1757d',
							),
							
							array(
								'id'       => 'foreground_accent_color',
								'title'    => esc_html__('Foreground Accent Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the foreground accent color', 'achilles-framework'),
								'type'     => 'color',
								'default'  => '#fff',
							),
							
							array(
								'id'       => 'content_skin',
								'title'    => esc_html__('Content Skin', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the content color skin', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_color_skin(),
								'default'  => 'skin-light'
							),
							array(
								'id'       => 'content_background_color',
								'title'    => esc_html__('Content Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom content background color.', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => ''
							)
						)
					),
					array(
						'id'             => 'section_color_group_top_drawer',
						'title'          => esc_html__('Top Drawer', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'required'       => array('top_drawer_mode', '!=', 'hide'),
						'fields'         => array(
							array(
								'id'          => 'top_drawer_skin',
								'title'       => esc_html__('Top Drawer Skin', 'achilles-framework'),
								'subtitle'    => esc_html__('Specify the top drawer color skin', 'achilles-framework'),
								'type'        => 'selectize',
								'placeholder' => esc_html__('Select Color Skin', 'achilles-framework'),
								'options'     => G5P()->settings()->get_color_skin(true),
								'default'     => 'skin-dark'
							),
							array(
								'id'       => 'top_drawer_background_color',
								'title'    => esc_html__('Top Drawer Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom top drawer background color.', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => ''
							)
						)
					),
					array(
						'id'             => 'section_color_group_header',
						'title'          => esc_html__('Header', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							array(
								'id'       => 'header_skin',
								'title'    => esc_html__('Header Skin', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the header color skin', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_color_skin(),
								'default'  => 'skin-light'
							),
							array(
								'id'       => 'header_background_color',
								'title'    => esc_html__('Header Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom header background color', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => ''
							),
							array(
								'id'       => 'header_sticky_skin',
								'title'    => esc_html__('Header Sticky Skin', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the header sticky color skin', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_color_skin(),
								'default'  => 'skin-light',
								'required' => array(
									array('header_sticky_enable', '=', 'on'),
									array('header_layout', 'not in', array('header-6', 'header-7'))
								)
							),
							array(
								'id'       => 'header_sticky_background_color',
								'title'    => esc_html__('Header Sticky Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom header sticky background color', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => '',
								'required' => array(
									array('header_sticky_enable', '=', 'on'),
									array('header_layout', 'not in', array('header-6', 'header-7'))
								)
							),
							array(
								'id'     => 'section_color_menu',
								'title'  => esc_html__('Menu', 'achilles-framework'),
								'type'   => 'group',
								'required' => array('header_layout', 'not in', array('header-6', 'header-7')),
								'fields' => array(
									array(
										'id'       => 'navigation_skin',
										'title'    => esc_html__('Navigation Skin', 'achilles-framework'),
										'subtitle' => esc_html__('Specify the navigation color skin', 'achilles-framework'),
										'type'     => 'select',
										'options'  => G5P()->settings()->get_color_skin(),
										'default'  => 'skin-light',
										'required' => array('header_layout', 'in', array('header-1','header-2','header-5'))
									),
									array(
										'id'       => 'navigation_background_color',
										'title'    => esc_html__('Navigation Background Color', 'achilles-framework'),
										'subtitle' => esc_html__('Specify a custom navigation background color', 'achilles-framework'),
										'type'     => 'color',
										'alpha'    => true,
										'default'  => '',
										'required' => array('header_layout', 'in', array('header-1','header-2','header-5'))
									),
									array(
										'id'          => 'sub_menu_skin',
										'title'       => esc_html__('Sub Menu Skin', 'achilles-framework'),
										'type'        => 'select',
										'placeholder' => esc_html__('Select Color Skin', 'achilles-framework'),
										'options'     => G5P()->settings()->get_color_skin(),
										'default'     => 'skin-light'
									),
									array(
										'id'       => 'sub_menu_background_color',
										'title'    => esc_html__('Sub Menu Background Color', 'achilles-framework'),
										'subtitle' => esc_html__('Specify a custom sub menu background color', 'achilles-framework'),
										'type'     => 'color',
										'alpha'    => true,
										'default'  => ''
									),

								)
							),
							array(
								'id'       => 'section_color_canvas_sidebar',
								'title'    => esc_html__('Canvas Sidebar', 'achilles-framework'),
								'type'     => 'group',
								'fields'   => array(
									array(
										'id'       => 'canvas_sidebar_skin',
										'title'    => esc_html__('Canvas Sidebar Skin', 'achilles-framework'),
										'subtitle' => esc_html__('Specify the canvas sidebar color skin', 'achilles-framework'),
										'type'     => 'select',
										'options'  => G5P()->settings()->get_color_skin(),
										'default'  => 'skin-dark'
									),
									array(
										'id'       => 'canvas_sidebar_background_color',
										'title'    => esc_html__('Canvas Sidebar Background Color', 'achilles-framework'),
										'subtitle' => esc_html__('Specify a custom canvas sidebar background color', 'achilles-framework'),
										'type'     => 'color',
										'alpha'    => true,
										'default'  => ''
									)
								)
							),
						)
					),
					
					array(
						'id'             => 'section_color_group_header_mobile',
						'title'          => esc_html__('Header Mobile', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'fields'         => array(
							array(
								'id'       => 'mobile_header_skin',
								'title'    => esc_html__('Header Mobile Skin', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the header mobile color skin', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_color_skin(),
								'default'  => 'skin-light'
							),
							array(
								'id'       => 'mobile_header_background_color',
								'title'    => esc_html__('Header Mobile Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom header mobile background color', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => ''
							),
						)
					),

					array(
						'id'             => 'section_color_group_page_title',
						'title'          => esc_html__('Page Title', 'achilles-framework'),
						'type'           => 'group',
						'toggle_default' => false,
						'required'       => array('page_title_enable', '=', 'on'),
						'fields'         => array(
							array(
								'id'       => 'page_title_skin',
								'title'    => esc_html__('Page Title Skin', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the page title color skin', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_color_skin(true),
								'default'  => '0'
							),
							array(
								'id'       => 'page_title_background_color',
								'title'    => esc_html__('Page Title Background Color', 'achilles-framework'),
								'subtitle' => esc_html__('Specify a custom page title background color', 'achilles-framework'),
								'type'     => 'color',
								'alpha'    => true,
								'default'  => ''
							),
						)
					)
				)
			);
		}
		
		/**
		 * Get Config Section Connections
		 *
		 * @return array
		 */
		public function get_config_section_connections()
		{
			return array(
				'id'              => 'section_connections',
				'title'           => esc_html__('Connections', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-share',
				'general_options' => true,
				'fields'          => array(
					array(
						'id'     => 'section_connections_group_social_share',
						'title'  => esc_html__('Social Share', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'       => 'social_share',
								'title'    => esc_html__('Social Share', 'achilles-framework'),
								'subtitle' => esc_html__('Select active social share links and sort them', 'achilles-framework'),
								'type'     => 'sortable',
								'options'  => G5P()->settings()->get_social_share(),
								'default'  => array(
									'facebook'  => 'facebook',
									'twitter'   => 'twitter',
									'pinterest' => 'pinterest',
								)
							),
						)
					),
					array(
						'id'     => 'section_connections_group_social_networks',
						'title'  => esc_html__('Social Networks', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							array(
								'id'             => 'social_networks',
								'title'          => esc_html__('Social Networks', 'achilles-framework'),
								'desc'           => esc_html__('Define here all the social networks you will need.', 'achilles-framework'),
								'type'           => 'panel',
								'toggle_default' => false,
								'default'        => G5P()->settings()->get_social_networks_default(),
								'panel_title'    => 'social_name',
								'fields'         => array(
									array(
										'id'       => 'social_name',
										'title'    => esc_html__('Title', 'achilles-framework'),
										'subtitle' => esc_html__('Enter your social network name', 'achilles-framework'),
										'type'     => 'text',
									),
									array(
										'id'         => 'social_id',
										'title'      => esc_html__('Unique Social Id', 'achilles-framework'),
										'subtitle'   => esc_html__('This value is created automatically and it shouldn\'t be edited unless you know what you are doing.', 'achilles-framework'),
										'type'       => 'text',
										'input_type' => 'unique_id',
										'default'    => 'social-'
									),
									array(
										'id'       => 'social_icon',
										'title'    => esc_html__('Social Network Icon', 'achilles-framework'),
										'subtitle' => esc_html__('Specify the social network icon', 'achilles-framework'),
										'type'     => 'icon',
									),
									array(
										'id'       => 'social_link',
										'title'    => esc_html__('Social Network Link', 'achilles-framework'),
										'subtitle' => esc_html__('Enter your social network link', 'achilles-framework'),
										'type'     => 'text',
									),
									array(
										'id'       => 'social_color',
										'title'    => esc_html__('Social Network Color', 'achilles-framework'),
										'subtitle' => sprintf(wp_kses_post(__('Specify the social network color. Reference in <a target="_blank" href="%s">brandcolors.net</a>', 'achilles-framework')), 'https://brandcolors.net/'),
										'type'     => 'color'
									)
								)
							)
						)
					),
				)
			);
		}
		
		/**
		 * Get Config Section Blog
		 *
		 * @return array
		 */
		
		public function get_config_section_blog()
		{
			return array(
				'id'              => 'section_blog',
				'title'           => esc_html__('Blog', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-media-text',
				'general_options' => true,
				'fields'          => array(
					$this->get_config_section_blog_listing('', '', false, array(
						$this->get_config_toggle(array(
							'id'       => "feature_post_layout_enable",
							'title'    => esc_html__('Feature Post', 'achilles-framework'),
							'subtitle' => esc_html__('Turn Off this option if you want to hide feature post on single blog', 'achilles-framework'),
							'default'  => 'off',
						)),
						array(
							'id'       => "feature_post_position",
							'title'    => esc_html__('Feature Post Position', 'achilles-framework'),
							'subtitle' => esc_html__('Specify your feature post position mode', 'achilles-framework'),
							'type'     => 'select',
							'options'  => G5P()->settings()->get_feature_post_position($inherit = false),
							'default'  => 'inside-content',
							'required' => array("feature_post_layout_enable", '=', 'on')
						),
						array(
							'id'       => "feature_post_layout",
							'title'    => esc_html__('Feature Post Layout', 'achilles-framework'),
							'subtitle' => esc_html__('Specify your feature post layout', 'achilles-framework'),
							'type'     => 'image_set',
							'options'  => G5P()->settings()->get_feature_post_layout($inherit = false),
							'default'  => $inherit ? '' : 'feature-1',
							'required' => array("feature_post_layout_enable", '=', 'on')
						),
						array(
							'id'       => "feature_post_columns_gutter",
							'title'    => esc_html__('Feature Post Columns Gutter', 'achilles-framework'),
							'subtitle' => esc_html__('Specify your horizontal space between post.', 'achilles-framework'),
							'type'     => 'select',
							'options'  => G5P()->settings()->get_post_columns_gutter($inherit),
							'default'  => $inherit ? '-1' : '40',
							'required' => array("feature_post_layout_enable", '=', 'on')
						),
						$this->get_config_toggle(array(
							'id'      => 'blog_filter_enable',
							'title'   => esc_html__('Show Category Filter', 'achilles-framework'),
							'default' => ''
						))
					)),
					$this->get_config_section_blog_listing(esc_html__('Search Listing', 'achilles-framework'), 'search', true),
					$this->get_config_group_single_blog()
				)
			);
		}
		
		
		/**
		 * Get Config group single blog
		 *
		 * @return array
		 */
		public function get_config_group_single_blog()
		{
			return array(
				'id'     => 'section_blog_group_single_blog',
				'title'  => esc_html__('Single Blog', 'achilles-framework'),
				'type'   => 'group',
				'fields' => array(
					array(
						'id'       => 'single_post_layout',
						'title'    => esc_html__('Post Layout', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your post layout', 'achilles-framework'),
						'type'     => 'image_set',
						'options'  => G5P()->settings()->get_single_post_layout(),
						'default'  => 'layout-1'
					),
					$this->get_config_toggle(array(
						'id'       => 'single_feature_image_enable',
						'title'    => esc_html__('Feature Image', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide Feature Image area on single blog', 'achilles-framework'),
						'default'  => '',
						'required' => array('single_post_layout', 'not in', array('layout-8', 'layout-9'))
					)),
					$this->get_config_toggle(array(
						'id'       => 'single_reading_process_enable',
						'title'    => esc_html__('Reading Process', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide reading process on single blog', 'achilles-framework'),
						'default'  => 'on'
					)),
					$this->get_config_toggle(array(
						'id'       => 'single_tag_enable',
						'title'    => esc_html__('Tags', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide tags on single blog', 'achilles-framework'),
						'default'  => 'on'
					)),
					$this->get_config_toggle(array(
						'id'       => 'single_share_enable',
						'title'    => esc_html__('Share', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide share on single blog', 'achilles-framework'),
						'default'  => 'on'
					)),
					$this->get_config_toggle(array(
						'id'       => 'single_navigation_enable',
						'title'    => esc_html__('Navigation', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide navigation on single blog', 'achilles-framework'),
						'default'  => 'on'
					)),
					$this->get_config_toggle(array(
						'id'       => 'single_author_info_enable',
						'title'    => esc_html__('Author Info', 'achilles-framework'),
						'subtitle' => esc_html__('Turn Off this option if you want to hide author info area on single blog', 'achilles-framework'),
						'default'  => 'on'
					)),
					array(
						'id'       => 'author_info_layout',
						'title'    => esc_html__('Author Info Layout', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your author info layout', 'achilles-framework'),
						'type'     => 'image_set',
						'options'  => G5P()->settings()->get_author_info_layout(),
						'default'  => 'author-layout-1',
						'required' => array('single_author_info_enable', '=', 'on')
					),
					array(
						'id'      => 'single_post_ordinal',
						'title'   => esc_html__('Single Post Ordinal', 'achilles-framework'),
						'type'    => 'sortable',
						'options' => G5P()->settings()->get_single_post_ordinal(),
						'default' => array(
							'related-post'  => 'related-post',
							'content-block' => 'content-block',
							'comment'       => 'comment'
						),
					),
					array(
						'id'     => 'group_single_related_posts',
						'title'  => esc_html__('Related Posts', 'achilles-framework'),
						'type'   => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id'       => 'single_related_post_enable',
								'title'    => esc_html__('Related Posts', 'achilles-framework'),
								'subtitle' => esc_html__('Turn Off this option if you want to hide related posts area on single blog', 'achilles-framework'),
								'default'  => 'on'
							)), array(
								'id'       => 'single_related_layout',
								'title'    => esc_html__('Related Posts Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your related posts layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_related_post_layout(),
								'default'  => 'related-post-layout-1',
								'required' => array('single_related_post_enable', '=', 'on')
							),
							array(
								'id'       => 'single_related_post_algorithm',
								'title'    => esc_html__('Related Posts Algorithm', 'achilles-framework'),
								'subtitle' => esc_html__('Specify the algorithm of related posts', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_related_post_algorithm(),
								'default'  => 'cat',
								'required' => array('single_related_post_enable', '=', 'on')
							),
							$this->get_config_toggle(array(
								'id'       => 'single_related_post_carousel_enable',
								'title'    => esc_html__('Carousel Mode', 'achilles-framework'),
								'subtitle' => esc_html__('Turn On this option if you want to enable carousel mode', 'achilles-framework'),
								'default'  => 'on',
								'required' => array('single_related_post_enable', '=', 'on')
							)),
							array(
								'id'         => 'single_related_post_per_page',
								'title'      => esc_html__('Posts Per Page', 'achilles-framework'),
								'subtitle'   => esc_html__('Enter number of posts per page you want to display', 'achilles-framework'),
								'type'       => 'text',
								'input_type' => 'number',
								'default'    => 6,
								'required'   => array('single_related_post_enable', '=', 'on')
							),
							array(
								'id'       => 'single_related_post_columns_gutter',
								'title'    => esc_html__('Post Columns Gutter', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your horizontal space between post.', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_post_columns_gutter(),
								'default'  => '40',
								'required' => array('single_related_post_enable', '=', 'on')
							),
							array(
								'id'       => 'single_related_post_columns_group',
								'title'    => esc_html__('Post Columns', 'achilles-framework'),
								'type'     => 'group',
								'required' => array('single_related_post_enable', '=', 'on'),
								'fields'   => array(
									array(
										'id'     => 'single_related_post_columns_row_1',
										'type'   => 'row',
										'col'    => 3,
										'fields' => array(
											array(
												'id'      => 'single_related_post_columns',
												'title'   => esc_html__('Large Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on large devices (>= 1200px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(),
												'default' => '3',
												'layout'  => 'full',
											),
											array(
												'id'      => 'single_related_post_columns_md',
												'title'   => esc_html__('Medium Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on medium devices (>= 992px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(),
												'default' => '3',
												'layout'  => 'full',
											),
											array(
												'id'      => 'single_related_post_columns_sm',
												'title'   => esc_html__('Small Devices', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on small devices (>= 768px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(),
												'default' => '2',
												'layout'  => 'full',
											),
											array(
												'id'      => 'single_related_post_columns_xs',
												'title'   => esc_html__('Extra Small Devices ', 'achilles-framework'),
												'desc'    => esc_html__('Specify your post columns on extra small devices (< 768px)', 'achilles-framework'),
												'type'    => 'select',
												'options' => G5P()->settings()->get_post_columns(),
												'default' => '2',
												'layout' => 'full',
											),
                                            array(
                                                'id' => "single_related_post_columns_mb",
                                                'title' => esc_html__('Extra Extra Small Devices ', 'achilles-framework'),
                                                'desc' => esc_html__('Specify your post columns on extra extra small devices (< 468px)', 'achilles-framework'),
                                                'type' => 'select',
                                                'options' => G5P()->settings()->get_post_columns(),
                                                'default' => '1',
                                                'layout' => 'full',
                                            )
										)
									),
								)
							),
							array(
								'id'       => 'single_related_post_paging',
								'title'    => esc_html__('Post Paging', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your post paging mode', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_post_paging_small_mode(),
								'default'  => 'none',
								'required' => array('single_related_post_enable', '=', 'on')
							),
							array(
								'id'       => 'single_related_post_animation',
								'title'    => esc_html__('Animation', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your post animation', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_animation(true),
								'default'  => '-1',
								'required' => array('single_related_post_enable', '=', 'on')
							),
						)
					),
					$this->get_config_content_block(array(
						'id'       => 'single_post_content_block',
						'title'    => esc_html__('Content Block Single Post', 'achilles-framework'),
						'subtitle' => esc_html__('Specify the Content Block to use as a single post content.', 'achilles-framework'),
					)),
					array(
						'id'       => 'comment_layout',
						'title'    => esc_html__('Comment Layout', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your comment layout', 'achilles-framework'),
						'type'     => 'image_set',
						'options'  => G5P()->settings()->get_comment_layout(),
						'default'  => 'comment-layout-2',
					),
				)
			);
		}
		

		/**
		 * Get Config Section Customize Css & Javascript
		 *
		 * @return array
		 */
		public function get_config_section_code()
		{
			return array(
				'id'              => 'section_code',
				'title'           => esc_html__('Css & Javascript', 'achilles-framework'),
				'icon'            => 'dashicons dashicons-editor-code',
				'general_options' => true,
				'fields'          => array(
					array(
						'id'       => 'custom_css',
						'title'    => esc_html__('Custom Css', 'achilles-framework'),
						'subtitle' => esc_html__('Enter here your custom CSS. Please do not include any style tags.', 'achilles-framework'),
						'type'     => 'ace_editor',
						'mode'     => 'css',
						'theme'    => 'monokai',
						'min_line' => 20
					),
					array(
						'id'       => 'custom_js',
						'title'    => esc_html__('Custom Javascript', 'achilles-framework'),
						'subtitle' => esc_html__('Enter here your custom javascript code. Please do not include any script tags.', 'achilles-framework'),
						'type'     => 'ace_editor',
						'mode'     => 'javascript',
						'theme'    => 'monokai',
						'min_line' => 20
					),
				)
			);
		}
		
		/**
		 * Get Config Content Block
		 *
		 * @param $id
		 * @param array $args
		 * @param bool $inherit
		 * @return array
		 */
		public function get_config_content_block($args = array())
		{
			$defaults = array(
				'title'       => esc_html__('Content Block', 'achilles-framework'),
				'placeholder' => esc_html__('Select Content Block', 'achilles-framework'),
				'type'        => 'selectize',
				'allow_clear' => true,
				'data'        => G5P()->cpt()->get_content_block_post_type(),
				'data_args'   => array(
					'numberposts' => -1,
				)
			);
			
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		/**
		 * Get Config Sidebar Layout
		 *
		 * @param $id
		 * @param bool $inherit
		 * @param array $args
		 * @return array
		 */
		public function get_config_sidebar_layout($args = array(), $inherit = false)
		{
			$defaults = array(
				'title'   => esc_html__('Sidebar Layout', 'achilles-framework'),
				'type'    => 'image_set',
				'options' => G5P()->settings()->get_sidebar_layout($inherit),
				'default' => $inherit ? '' : 'right'
			);
			
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		/**
		 * Get Config Sidebar
		 *
		 * @param $id
		 * @param array $args
		 * @param $inherit
		 * @return array
		 */
		public function get_config_sidebar($args = array(), $inherit = false)
		{
			$defaults = array(
				'title'       => esc_html__('Sidebar', 'achilles-framework'),
				'type'        => 'selectize',
				'placeholder' => esc_html__('Select Sidebar', 'achilles-framework'),
				'data'        => 'sidebar',
				'allow_clear' => true,
				'default'     => ''
			);
			
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		
		/**
		 * Get Config Border Bottom
		 *
		 * @param $id
		 * @param array $args
		 * @param bool $inherit
		 * @return array
		 */
		public function get_config_border_bottom($id, $args = array(), $inherit = false)
		{
			$defaults = array(
				'id'       => $id,
				'type'     => 'select',
				'title'    => esc_html__('Border Bottom', 'achilles-framework'),
				'subtitle' => esc_html__('Specify the border bottom mode.', 'achilles-framework'),
				'options'  => G5P()->settings()->get_border_layout($inherit),
				'default'  => $inherit ? '' : 'none'
			);
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		/**
		 * Get Config Group Header Customize
		 *
		 * @param $id
		 * @param $title
		 * @param $prefixId
		 * @param array $default
		 * @param array $required
		 * @return array
		 */
		public function get_config_group_header_customize($id, $title, $prefixId, $default = array(), $required = array())
		{
			return array(
				'id'             => $id,
				'title'          => $title,
				'type'           => 'group',
				'toggle_default' => true,
				'required'       => $required,
				'fields'         => array(
					array(
						'id'      => $prefixId,
						'title'   => esc_html__('Items', 'achilles-framework'),
						'type'    => 'sortable',
						'options' => G5P()->settings()->get_header_customize(),
						'default' => $default
					),
					$this->get_config_sidebar(array(
						'id'       => "{$prefixId}_sidebar",
						'required' => array($prefixId, 'contain', 'sidebar')
					)),
					array(
						'id'          => "{$prefixId}_social_networks",
						'title'       => esc_html__('Social Networks', 'achilles-framework'),
						'type'        => 'selectize',
						'multiple'    => true,
						'drag'        => true,
						'placeholder' => esc_html__('Select Social Networks', 'achilles-framework'),
						'options'     => G5P()->settings()->get_social_networks(),
						'required'    => array($prefixId, 'contain', 'social-networks')
					),
					array(
						'id'       => "{$prefixId}_social_networks_hover_color",
						'title'    => esc_html__('Social Networks Hover Color', 'achilles-framework'),
						'type'     => 'select',
						'required' => array($prefixId, 'contain', 'social-networks'),
						'options'  => array(
							'color-dark'   => esc_html__('Dark', 'achilles-framework'),
							'color-white'  => esc_html__('Light', 'achilles-framework'),
							'color-accent' => esc_html__('Accent', 'achilles-framework'),
						),
						'default'  => 'color-accent'
					),
					array(
						'id'       => "{$prefixId}_custom_html",
						'title'    => esc_html__('Custom Html Content', 'achilles-framework'),
						'type'     => 'ace_editor',
						'mode'     => 'html',
						'required' => array($prefixId, 'contain', 'custom-html')
					),
					array(
						'id'       => "{$prefixId}_canvas_sidebar_title",
						'title'    => esc_html__('Canvas Siderbar Title', 'achilles-framework'),
						'type'     => 'text',
						'required' => array($prefixId, 'contain', 'canvas-sidebar')
					),
					array(
						'id'       => "{$prefixId}_canvas_sidebar_title_color",
						'title'    => esc_html__('Canvas Siderbar Title Color', 'achilles-framework'),
						'type'     => 'select',
						'required' => array($prefixId, 'contain', 'canvas-sidebar'),
						'options'  => array(
							'color-dark'   => esc_html__('Dark', 'achilles-framework'),
							'color-white'  => esc_html__('Light', 'achilles-framework'),
							'color-accent' => esc_html__('Accent', 'achilles-framework'),
						),
						'default'  => 'color-dark'
					),
					array(
						'id'       => "{$prefixId}_canvas_sidebar_title_bg_color",
						'title'    => esc_html__('Canvas Siderbar Title Background Color', 'achilles-framework'),
						'type'     => 'select',
						'required' => array($prefixId, 'contain', 'canvas-sidebar'),
						'options'  => array(
							'bg-accent'      => esc_html__('Accent', 'achilles-framework'),
							'bg-transparent' => esc_html__('Transparent', 'achilles-framework'),
						),
						'default'  => 'bg-transparent'
					),
					$this->get_config_spacing("{$prefixId}_spacing", array(
						'title'   => esc_html__('Items Spacing', 'achilles-framework'),
						'default' => 40
					)),
					array(
						'id'      => "{$prefixId}_custom_css",
						'type'    => 'text',
						'title'   => esc_html__('Custom Css Class', 'achilles-framework'),
						'default' => ''
					)
				)
			);
		}
		
		/**
		 * Get Config Spacing
		 *
		 * @param $id
		 * @param array $args
		 * @return array
		 */
		public function get_config_spacing($id, $args = array())
		{
			$defaults = array(
				'id'         => $id,
				'type'       => 'slider',
				'js_options' => array(
					'step' => 1,
					'min'  => 1,
					'max'  => 100
				),
				'default'    => 40,
			);
			
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		
		/**
		 * Get Toggle Config
		 *
		 * @param array $args
		 * @param bool $inherit
		 * @return array
		 */
		public function get_config_toggle($args = array(), $inherit = false)
		{
			
			if (!$inherit) {
				$defaults = array(
					'type' => 'switch'
				);
			} else {
				$defaults = array(
					'type'    => 'button_set',
					'options' => G5P()->settings()->get_toggle($inherit),
					'default' => '',
				);
			}
			$defaults = wp_parse_args($args, $defaults);
			return $defaults;
		}
		
		public function get_config_section_blog_listing($title = '', $prefix = '', $inherit = false, $addition = array())
		{
			if ($prefix !== '') {
				$prefix = "{$prefix}_";
			}
			
			if ($title === '') {
				$title = esc_html__('Blog Listing', 'achilles-framework');
			}
			
			$fields = array_merge(
				$addition,
				array(
					array(
						'id'       => "{$prefix}post_layout",
						'title'    => esc_html__('Post Layout', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your post layout', 'achilles-framework'),
						'type'     => 'image_set',
						'options'  => G5P()->settings()->get_post_layout($inherit),
						'default'  => $inherit ? '' : 'large-image'
					)
				),
				array(
					array(
						'id'       => "{$prefix}post_columns_gutter",
						'title'    => esc_html__('Post Columns Gutter', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your horizontal space between post.', 'achilles-framework'),
						'type'     => 'select',
						'options'  => G5P()->settings()->get_post_columns_gutter($inherit),
						'default'  => $inherit ? '-1' : '40',
						'required' => array("{$prefix}post_layout", 'in', array('grid-image', 'grid-image-2', 'grid-image-3', 'masonry-image'))
					),
					array(
						'id'       => "{$prefix}post_columns_group",
						'title'    => esc_html__('Post Columns', 'achilles-framework'),
						'type'     => 'group',
						'required' => array("{$prefix}post_layout", 'in', array('grid-image', 'grid-image-2', 'grid-image-3', 'masonry-image')),
						'fields'   => array(
							array(
								'id'     => "{$prefix}post_columns_row_1",
								'type'   => 'row',
								'col'    => 3,
								'fields' => array(
									array(
										'id'      => "{$prefix}post_columns",
										'title'   => esc_html__('Large Devices', 'achilles-framework'),
										'desc'    => esc_html__('Specify your post columns on large devices (>= 1200px)', 'achilles-framework'),
										'type'    => 'select',
										'options' => G5P()->settings()->get_post_columns($inherit),
										'default' => $inherit ? '-1' : '2',
										'layout'  => 'full',
									),
									array(
										'id'      => "{$prefix}post_columns_md",
										'title'   => esc_html__('Medium Devices', 'achilles-framework'),
										'desc'    => esc_html__('Specify your post columns on medium devices (>= 992px)', 'achilles-framework'),
										'type'    => 'select',
										'options' => G5P()->settings()->get_post_columns($inherit),
										'default' => $inherit ? '-1' : '2',
										'layout'  => 'full',
									),
									array(
										'id'      => "{$prefix}post_columns_sm",
										'title'   => esc_html__('Small Devices', 'achilles-framework'),
										'desc'    => esc_html__('Specify your post columns on small devices (>= 768px)', 'achilles-framework'),
										'type'    => 'select',
										'options' => G5P()->settings()->get_post_columns($inherit),
										'default' => $inherit ? '-1' : '1',
										'layout'  => 'full',
									),
									array(
										'id'      => "{$prefix}post_columns_xs",
										'title'   => esc_html__('Extra Small Devices ', 'achilles-framework'),
										'desc'    => esc_html__('Specify your post columns on extra small devices (< 768px)', 'achilles-framework'),
										'type'    => 'select',
										'options' => G5P()->settings()->get_post_columns($inherit),
										'default' => $inherit ? '-1' : '1',
										'layout'  => 'full',
									)
								)
							),
						)
					),
					array(
						'id'         => "{$prefix}posts_per_page",
						'title'      => esc_html__('Posts Per Page', 'achilles-framework'),
						'subtitle'   => esc_html__('Enter number of posts per page you want to display. Default 10', 'achilles-framework'),
						'type'       => 'text',
						'input_type' => 'number',
						'default'    => $inherit ? '' : 10
					),
					array(
						'id'       => "{$prefix}post_paging",
						'title'    => esc_html__('Post Paging', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your post paging mode', 'achilles-framework'),
						'type'     => 'select',
						'options'  => G5P()->settings()->get_post_paging_mode($inherit),
						'default'  => $inherit ? '-1' : 'pagination'
					),
					array(
						'id'       => "{$prefix}post_animation",
						'title'    => esc_html__('Animation', 'achilles-framework'),
						'subtitle' => esc_html__('Specify your post animation', 'achilles-framework'),
						'type'     => 'select',
						'options'  => G5P()->settings()->get_animation($inherit),
						'default'  => $inherit ? '-1' : 'none'
					),
				));
			
			if ($prefix === '') {
				$fields[] = array(
					'id'          => 'post_ads',
					'title'       => esc_html__('Advertisement', 'achilles-framework'),
					'desc'        => esc_html__('Define here all the advertisement for listing post you will need.', 'achilles-framework'),
					'type'        => 'panel',
					'required'    => array('post_layout', 'in', array('large-image', 'medium-image')),
					'panel_title' => 'name',
					'fields'      => array(
						array(
							'id'       => 'name',
							'title'    => esc_html__('Title', 'achilles-framework'),
							'subtitle' => esc_html__('Enter your advertisement name', 'achilles-framework'),
							'type'     => 'text',
						),
						array(
							'id'       => 'content',
							'title'    => esc_html__('Content', 'achilles-framework'),
							'subtitle' => esc_html__('Enter your advertisement content', 'achilles-framework'),
							'type'     => 'editor',
						),
						array(
							'id'         => 'position',
							'title'      => esc_html__('Position', 'achilles-framework'),
							'subtitle'   => esc_html__('Enter your advertisement position', 'achilles-framework'),
							'desc'       => esc_html__('After how many post the ad will display.', 'achilles-framework'),
							'type'       => 'text',
							'input_type' => 'number'
						),
					)
				);
			}
			if ($prefix === 'search_') {
				$fields[] = array(
					'id'       => 'search_post_type',
					'type'     => 'checkbox_list',
					'title'    => esc_html__('Post Type For Search', 'achilles-framework'),
					'options'  => G5P()->settings()->get_search_ajax_popup_post_type(),
					'multiple' => true,
					'default'  => array('post'),
				);
			}
			$options = array(
				'id'     => "{$prefix}section_blog_group_blog_listing",
				'title'  => $title,
				'type'   => 'group',
				'fields' => $fields
			);
			return $options;
		}
		
		/**
		 * Get preset config
		 *
		 * @param array $args
		 * @return array
		 */
		public function get_config_preset($args = array())
		{
			$defaults = array(
				'title'       => esc_html__('Preset', 'achilles-framework'),
				'type'        => 'selectize',
				'allow_clear' => true,
				'data'        => 'preset',
				'data-option' => G5P()->getOptionName(),
				'create_link' => admin_url('admin.php?page=gsf_options'),
				'edit_link'   => admin_url('admin.php?page=gsf_options'),
				'placeholder' => esc_html__('Select Preset', 'achilles-framework'),
				'multiple'    => false,
				'desc'        => esc_html__('Optionally you can choose to override the setting that is used on the page', 'achilles-framework'),
			);
			return wp_parse_args($args, $defaults);
		}
		
		
		/**
		 * Popup Setting Section
		 * *******************************************************
		 */
		public function get_config_section_popup()
		{
			return array(
				'id' => 'section_popup',
				'title' => esc_html__('Popup Setting', 'achilles-framework'),
				'icon' => 'dashicons dashicons-editor-expand',
				'general_options' => true,
				'fields' => array(
					array(
						'id' => 'section_popup_mailchimp_group_general',
						'title' => esc_html__('Mailchimp Popup', 'achilles-framework'),
						'type' => 'group',
						'fields' => array(
							$this->get_config_toggle(array(
								'id' => 'mailchimp_popup_enable',
								'title' => esc_html__('Popup Enable?', 'achilles-framework'),
								'default' => ''
							)),
							array(
								'id'       => 'mailchimp_popup_image',
								'title'    => esc_html__('Popup Image', 'achilles-framework'),
								'type'     => 'image',
								'required' => array('mailchimp_popup_enable', '=', 'on')
							),
							array(
								'id' => 'mailchimp_popup_title',
								'type' => 'text',
								'title' => esc_html__('Popup title', 'achilles-framework'),
								'default' => esc_html__('Newsletter', 'achilles-framework'),
								'required' => array('mailchimp_popup_enable', '=', 'on')
							),
							array(
								'id' => 'mailchimp_popup_description',
								'type' => 'text',
								'title' => esc_html__('Popup description', 'achilles-framework'),
								'default' => esc_html__('Enter you email address to receive all news from our awesome Website', 'achilles-framework'),
								'required' => array('mailchimp_popup_enable', '=', 'on')
							),
							array(
								'id' => 'mailchimp_popup_shortcode',
								'type' => 'text',
								'title' => esc_html__('Mailchimp Shortcode', 'achilles-framework'),
								'required' => array('mailchimp_popup_enable', '=', 'on')
							),
							array(
								'id' => 'mailchimp_popup_timeout',
								'type' => 'text',
								'input_type' => 'number',
								'title' => esc_html__('Timeout show popup', 'achilles-framework'),
								'subtitle' => esc_html__('Enter number of timeout show popup when page loaded. Default 500 (milisecond)', 'achilles-framework'),
								'default' => 500,
								'required' => array('mailchimp_popup_enable', '=', 'on')
							),
						),
					)
				)
			);
		}
	}
}