<?php
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}

if (!class_exists('G5P_Inc_Config_Term_Meta')) {
	class G5P_Inc_Config_Term_Meta
	{
		/*
	 * loader instances
	 */
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		public function init()
		{
			// Defined Theme Options
			add_filter('gsf_term_meta_config', array($this, 'register_term_meta'));
		}
		
		public function getTaxonomy()
		{
			return apply_filters('gsf_term_meta_taxonomy', array('category'));
		}
		
		public function register_term_meta($configs)
		{
			$prefix = G5P()->getMetaPrefix();
			
			$configs['gsf_taxonomy_setting'] = array(
				'name'     => esc_html__('Advance Setting', 'achilles-framework'),
				'layout'   => 'horizontal',
				'taxonomy' => $this->getTaxonomy(),
				'fields'   => array(
					array(
						'id'       => "{$prefix}cat_highlight_color",
						'title'    => esc_html__('Highlight Color', 'achilles-framework'),
						'subtitle' => esc_html__('Specify the category highlight color', 'achilles-framework'),
						'type'     => 'color',
						'default'  => '#0b0b0b',
					),
					array(
						'id'     => "{$prefix}group_page_title",
						'type'   => 'group',
						'title'  => esc_html__('Page Title', 'achilles-framework'),
						'fields' => array(
							G5P()->configOptions()->get_config_toggle(array(
								'title' => esc_html__('Page Title Enable', 'achilles-framework'),
								'id'    => "{$prefix}page_title_enable"
							), true),
							G5P()->configOptions()->get_config_content_block(array(
								'id'       => "{$prefix}page_title_content_block",
								'desc'     => esc_html__('Specify the Content Block to use as a page title content.', 'achilles-framework'),
								'required' => array("{$prefix}page_title_enable", '!=', 'off')
							), true),
							
							array(
								'title'    => esc_html__('Custom Page title', 'achilles-framework'),
								'id'       => "{$prefix}page_title_content",
								'type'     => 'text',
								'default'  => '',
								'required' => array("{$prefix}page_title_enable", '!=', 'off'),
								'desc'     => esc_html__('Enter custom page title for this page', 'achilles-framework')
							)
						)
					),
					array(
						'id'     => "{$prefix}group_feature_post",
						'type'   => 'group',
						'title'  => esc_html__('Feature Post', 'achilles-framework'),
						'fields' => array(
							G5P()->configOptions()->get_config_toggle(array(
								'title' => esc_html__('Feature Post Enable', 'achilles-framework'),
								'id'    => "{$prefix}feature_post_layout_enable"
							), true),
							array(
								'id'       => "{$prefix}feature_post_position",
								'title'    => esc_html__('Feature Post Position', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your feature post position mode', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_feature_post_position($inherit = true),
								'default'  => $inherit ? '' : 'inside-content',
								'required' => array("{$prefix}feature_post_layout_enable", '=', 'on')
							),
							array(
								'id'       => "{$prefix}feature_post_layout",
								'title'    => esc_html__('Feature Post Layout', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your feature post layout', 'achilles-framework'),
								'type'     => 'image_set',
								'options'  => G5P()->settings()->get_feature_post_layout($inherit = true),
								'default'  => $inherit ? '' : 'feature-1',
								'required' => array("{$prefix}feature_post_layout_enable", '=', 'on')
							),
							array(
								'id'       => "{$prefix}feature_post_columns_gutter",
								'title'    => esc_html__('Feature Post Columns Gutter', 'achilles-framework'),
								'subtitle' => esc_html__('Specify your horizontal space between post.', 'achilles-framework'),
								'type'     => 'select',
								'options'  => G5P()->settings()->get_post_columns_gutter($inherit = true),
								'default'  => $inherit ? '' : '40',
								'required' => array("{$prefix}feature_post_layout_enable", '=', 'on')
							),
							G5P()->configOptions()->get_config_toggle(array(
								'id'    => "{$prefix}blog_filter_enable",
								'title' => esc_html__('Show Category Filter', 'achilles-framework'),
							), true),
						)
					)
				));
			
			
			return $configs;
		}
	}
}