<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}

if (!class_exists('G5P_Inc_Hook')) {
	class G5P_Inc_Hook
	{
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		public function init()
		{
			$this->addAction();
			$this->addFilter();
		}
		
		private function addAction()
		{
			add_action('init', array($this, 'registerAssets'), 0);
			add_action('wp', array(G5P()->helper(), 'getCurrentPreset'), 1);
			add_action('wp_enqueue_scripts', array($this, 'frontEndAssets'));
			add_action('admin_enqueue_scripts', array($this, 'adminAssets'));
			add_action('wp', array($this, 'setMetaBoxesToOption'), 20);
			add_action('wp', array($this, 'setTermMetaToOption'), 20);
			add_action('pre_get_posts', array($this, 'setPostLayoutToOption'), 20);
			add_action('wp', array($this, 'setPostSingleToOption'), 20);
			add_action('wp', array($this, 'setPageLayoutToOption'), 30);
			add_action('wp_ajax_g5plus_install_demo', array(G5P()->core()->dashboard()->installDemo(), 'installDemo'));
			add_action('init', array($this, 'allowedPostTags'));
			add_action('pre_get_posts', array($this, 'changePostPerPage'), 30);
			
			/* share */
			add_action('g5plus_single_post_share', array($this, 'socialShare'));
			add_action('g5plus_single_post_share_square', array($this, 'socialShareSquare'));
		}
		
		private function addFilter()
		{
			add_filter('gsf_theme_font_default', array($this, 'themeFontsDefault'));
			add_filter('gsf_plugin_url', array($this, 'changeSmartFrameworkUrl'));
			add_filter('gsf_theme_changelog_url', array($this, 'get_changelog_url'));
			add_filter('gsf-documentation-url', array($this, 'get_documentation_url'));
			add_filter('gsf-video-tutorials-url', array($this, 'get_video_tutorials_url'));
            add_filter('g5plus_editor_style',array($this,'editorStyle'));
		}
		
		public function get_changelog_url()
		{
			return 'http://themes.g5plus.net/achilles/changelog.html';
		}
		
		public function get_documentation_url()
		{
			return 'http://document.g5plus.net/achilles/';
		}
		
		public function get_video_tutorials_url()
		{
			return '#';
		}
		
		public function changeSmartFrameworkUrl($url)
		{
			$pluginName = G5P()->pluginName();
			return "{$pluginName}/libs/smart-framework";
		}

		public function themeFontsDefault($fonts)
		{
			return array(
				array(
					'family' => 'Josefin Sans',
					'kind'   => 'webfonts#webfont'
				),
				array(
					'family' => "Felix Titling",
					'kind'   => 'webfonts#webfont'
				),
				array(
					'family' => "Oswald",
					'kind'   => 'webfonts#webfont'
				),
			);
		}
		
		/**
		 * Register assets
		 */
		public function registerAssets()
		{
			G5P()->assets()->registerScript();
			G5P()->assets()->registerStyle();
		}
		
		public function frontEndAssets()
		{
			wp_enqueue_style(G5P()->assetsHandle('admin-bar'));
		}

        public function adminAssets()
        {
            wp_enqueue_style(G5P()->assetsHandle('admin-bar'));
            if ($this->isMetaPost()) {
                wp_enqueue_script(G5P()->assetsHandle('post-format'));
            }
        }

        public function isMetaPost($screen = null) {
            if ( ! ( $screen instanceof WP_Screen ) )
            {
                $screen = get_current_screen();
            }
            return 'post' == $screen->base && ($screen->post_type == 'post');
        }
		
		public function socialShare($args = array())
		{
			$defaults = array(
				'layout'         => 'classic',
				'show_title'     => false,
				'page_permalink' => '',
				'page_title'     => '',
			);
			$defaults = wp_parse_args($args, $defaults);
			G5P()->helper()->getTemplate('inc/templates/social-share', $defaults);
			
		}
		
		public function socialShareSquare()
		{
			$this->socialShare(array(
				'layout'         => 'square',
			));
		}
		public function setMetaBoxesToOption()
		{
			$postType = G5P()->configMetaBox()->getPostType();
			if (is_singular($postType) || is_singular('post')) {
				$main_layout = G5P()->metaBox()->get_main_layout();
				if ($main_layout !== '') {
					G5P()->options()->setOptions('main_layout', $main_layout);
				}
				
				
				$content_full_width = G5P()->metaBox()->get_content_full_width();
				if ($content_full_width !== '') {
					G5P()->options()->setOptions('content_full_width', $content_full_width);
				}
				
				$custom_content_padding = G5P()->metaBox()->get_custom_content_padding();
				if ($custom_content_padding === 'on') {
					G5P()->options()->setOptions('content_padding', G5P()->metaBox()->get_content_padding());
				}
				
				
				// sidebar layout
				$sidebar_layout = G5P()->metaBox()->get_sidebar_layout();
				if ($sidebar_layout !== '') {
					G5P()->options()->setOptions('sidebar_layout', $sidebar_layout);
				}
				
				// sidebar
				$sidebar = G5P()->metaBox()->get_sidebar();
				if ($sidebar !== '') {
					G5P()->options()->setOptions('sidebar', $sidebar);
				}
				
				$page_title_enable = G5P()->metaBox()->get_page_title_enable();
				if ($page_title_enable !== '') {
					G5P()->options()->setOptions('page_title_enable', $page_title_enable);
				}
				
				$page_title_content_block = G5P()->metaBox()->get_page_title_content_block();
				if ($page_title_content_block !== '') {
					G5P()->options()->setOptions('page_title_content_block', $page_title_content_block);
				}
			}
		}
		
		public function setTermMetaToOption()
		{
			$taxonomy = G5P()->configTermMeta()->getTaxonomy();
			if ((in_array('category', $taxonomy) && is_category()) || is_tax($taxonomy)) {
				$term = get_queried_object();
				if ($term && property_exists($term, 'term_id')) {
					$term_id = $term->term_id;
					
					$page_title_enable = G5P()->termMeta()->get_page_title_enable($term_id);
					if ($page_title_enable !== '') {
						G5P()->options()->setOptions('page_title_enable', $page_title_enable);
					}
					
					$page_title_content_block = G5P()->termMeta()->get_page_title_content_block($term_id);
					if ($page_title_content_block !== '') {
						G5P()->options()->setOptions('page_title_content_block', $page_title_content_block);
					}
					
					$feature_post_layout_enable = G5P()->termMeta()->get_feature_post_layout_enable($term_id);
					if ($feature_post_layout_enable !== '') {
						G5P()->options()->setOptions('feature_post_layout_enable', $feature_post_layout_enable);
					}
					$feature_post_position = G5P()->termMeta()->get_feature_post_position($term_id);
					if ($feature_post_position !== '') {
						G5P()->options()->setOptions('feature_post_position', $feature_post_position);
					}
					$feature_post_layout = G5P()->termMeta()->get_feature_post_layout($term_id);
					if ($feature_post_layout !== '') {
						G5P()->options()->setOptions('feature_post_layout', $feature_post_layout);
					}
					$feature_post_columns_gutter = G5P()->termMeta()->get_feature_post_columns_gutter($term_id);
					if ($feature_post_columns_gutter !== '') {
						G5P()->options()->setOptions('feature_post_columns_gutter', $feature_post_columns_gutter);
					}
					$blog_filter_enable = G5P()->termMeta()->get_blog_filter_enable($term_id);
					if ($blog_filter_enable !== '') {
						G5P()->options()->setOptions('blog_filter_enable', $blog_filter_enable);
					}
				}
			}
		}
		
		public function setPostSingleToOption()
		{
			if (is_singular('post')) {
				$single_post_layout = G5P()->metaBoxPost()->get_single_post_layout();
				if ($single_post_layout !== '') {
					G5P()->options()->setOptions('single_post_layout', $single_post_layout);
				}
				$single_feature_image_enable = G5P()->metaBoxPost()->get_single_feature_image_enable();
				if ($single_feature_image_enable !== '') {
					G5P()->options()->setOptions('single_feature_image_enable', $single_feature_image_enable);
				}
				$single_reading_process_enable = G5P()->metaBoxPost()->get_single_reading_process_enable();
				if ($single_reading_process_enable !== '') {
					G5P()->options()->setOptions('single_reading_process_enable', $single_reading_process_enable);
				}
				$single_tag_enable = G5P()->metaBoxPost()->get_single_tag_enable();
				if ($single_tag_enable !== '') {
					G5P()->options()->setOptions('single_tag_enable', $single_tag_enable);
				}
				$single_share_enable = G5P()->metaBoxPost()->get_single_share_enable();
				if ($single_share_enable !== '') {
					G5P()->options()->setOptions('single_share_enable', $single_share_enable);
				}
				$single_navigation_enable = G5P()->metaBoxPost()->get_single_navigation_enable();
				if ($single_navigation_enable !== '') {
					G5P()->options()->setOptions('single_navigation_enable', $single_navigation_enable);
				}
				$single_author_info_enable = G5P()->metaBoxPost()->get_single_author_info_enable();
				if ($single_author_info_enable !== '') {
					G5P()->options()->setOptions('single_author_info_enable', $single_author_info_enable);
				}
				$author_info_layout = G5P()->metaBoxPost()->get_author_info_layout();
				if ($author_info_layout !== '') {
					G5P()->options()->setOptions('author_info_layout', $author_info_layout);
				}
				$single_post_ordinal = G5P()->metaBoxPost()->get_single_post_ordinal();
				if ($single_post_ordinal !== '') {
					G5P()->options()->setOptions('single_post_ordinal', $single_post_ordinal);
				}
				$single_post_content_block = G5P()->metaBoxPost()->get_single_post_content_block();
				if ($single_post_content_block !== '') {
					G5P()->options()->setOptions('single_post_content_block', $single_post_content_block);
				}
				$comment_layout = G5P()->metaBoxPost()->get_comment_layout();
				if ($comment_layout !== '') {
					G5P()->options()->setOptions('comment_layout', $comment_layout);
				}
				
				// Related
				$single_related_post_enable = G5P()->metaBoxPost()->get_single_related_post_enable();
				if ($single_related_post_enable !== '') {
					G5P()->options()->setOptions('single_related_post_enable', $single_related_post_enable);
				}
				$single_related_layout = G5P()->metaBoxPost()->get_single_related_layout();
				if ($single_related_layout !== '') {
					G5P()->options()->setOptions('single_related_layout', $single_related_layout);
				}
				$single_related_post_algorithm = G5P()->metaBoxPost()->get_single_related_post_algorithm();
				if ($single_related_post_algorithm !== '') {
					G5P()->options()->setOptions('single_related_post_algorithm', $single_related_post_algorithm);
				}
				$single_related_post_carousel_enable = G5P()->metaBoxPost()->get_single_related_post_carousel_enable();
				if ($single_related_post_carousel_enable !== '') {
					G5P()->options()->setOptions('single_related_post_carousel_enable', $single_related_post_carousel_enable);
				}
				$single_related_post_per_page = G5P()->metaBoxPost()->get_single_related_post_per_page();
				if ($single_related_post_per_page !== '') {
					G5P()->options()->setOptions('single_related_post_per_page', $single_related_post_per_page);
				}
				$single_related_post_columns_gutter = G5P()->metaBoxPost()->get_single_related_post_columns_gutter();
				if ($single_related_post_columns_gutter !== '') {
					G5P()->options()->setOptions('single_related_post_columns_gutter', $single_related_post_columns_gutter);
				}
				$single_related_post_columns = G5P()->metaBoxPost()->get_single_related_post_columns();
				if ($single_related_post_columns !== '') {
					G5P()->options()->setOptions('single_related_post_columns', $single_related_post_columns);
				}
				
				$single_related_post_columns_md = G5P()->metaBoxPost()->get_single_related_post_columns_md();
				if ($single_related_post_columns_md !== '') {
					G5P()->options()->setOptions('single_related_post_columns_md', $single_related_post_columns_md);
				}
				$single_related_post_columns_sm = G5P()->metaBoxPost()->get_single_related_post_columns_sm();
				if ($single_related_post_columns_sm !== '') {
					G5P()->options()->setOptions('single_related_post_columns_sm', $single_related_post_columns_sm);
				}
				$single_related_post_columns_xs = G5P()->metaBoxPost()->get_single_related_post_columns_xs();
				if ($single_related_post_columns_xs !== '') {
					G5P()->options()->setOptions('single_related_post_columns_xs', $single_related_post_columns_xs);
				}
				$single_related_post_paging = G5P()->metaBoxPost()->get_single_related_post_paging();
				if ($single_related_post_paging !== '') {
					G5P()->options()->setOptions('single_related_post_paging', $single_related_post_paging);
				}
				$single_related_post_animation = G5P()->metaBoxPost()->get_single_related_post_animation();
				if ($single_related_post_animation !== '') {
					G5P()->options()->setOptions('single_related_post_animation', $single_related_post_animation);
				}
			}
		}
		
		public function changePostPerPage($wp_query)
		{
			$post_type = $wp_query->get('post_type');
			if (!is_admin() && $wp_query->is_main_query() && ($wp_query->is_home() || $wp_query->is_category() || $wp_query->is_tag() || ($wp_query->is_archive() && $post_type == 'post') || ($wp_query->is_search() && ((is_array($post_type) && in_array('post', $post_type) || $post_type == 'post'))))) {
				$posts_per_page = intval(G5P()->options()->get_posts_per_page());
				$custom_posts_per_page = isset($_GET['posts_per_page']) ? $_GET['posts_per_page'] : '';
				if (!empty($custom_posts_per_page)) {
					$posts_per_page = $custom_posts_per_page;
				}
				if (!empty($posts_per_page)) {
					$wp_query->set('posts_per_page', $posts_per_page);
				}
			}
		}
		
		public function setPostLayoutToOption()
		{
			if (is_admin()) return;
			
			global $post;
			$post_type = get_post_type($post);
			$options = &GSF()->adminThemeOption()->getOptions(G5P()->getOptionName());
			$custom_post_layout_settings = G5P()->settings()->get_custom_post_layout_settings();
			foreach ($custom_post_layout_settings as $key => $value) {
				if ((($key === 'search') && is_search() && !is_admin()) ||
					(($key === 'category') && is_category())
				) {
					$settings = array(
						'post_layout',
						'post_columns_gutter',
						'post_columns',
						'post_columns_md',
						'post_columns_sm',
						'post_columns_xs',
						'posts_per_page',
						'post_paging',
						'post_animation'
					);
					
					foreach ($settings as $setting) {
						$setting_value = G5P()->options()->getOptions("{$key}_{$setting}");
						if ($setting_value !== '') {
							$options[$setting] = $setting_value;
						}
					}
					break;
				}
			}
			
			// custom param
			if ((is_home() || is_category() || is_tag() || is_archive()) || (is_search() && ($post_type == 'post'))) {
				$post_layout = isset($_GET['post_layout']) ? $_GET['post_layout'] : '';
				if (array_key_exists($post_layout, G5P()->settings()->get_post_layout())) {
					G5P()->options()->setOptions('post_layout', $post_layout);
				}
				$post_columns = isset($_GET['post_columns']) ? $_GET['post_columns'] : '';
				if (in_array($post_columns, array('1', '2', '3', '4', '5', '6'))) {
					G5P()->options()->setOptions('post_columns', $post_columns);
				}
				$post_paging = isset($_GET['post_paging']) ? $_GET['post_paging'] : '';
				if (array_key_exists($post_paging, G5P()->settings()->get_post_paging_mode())) {
					G5P()->options()->setOptions('post_paging', $post_paging);
				}
				$post_columns_gutter = isset($_GET['post_columns_gutter']) ? $_GET['post_columns_gutter'] : '';
				if (array_key_exists($post_columns_gutter, G5P()->settings()->get_post_columns_gutter())) {
					G5P()->options()->setOptions('post_columns_gutter', $post_columns_gutter);
				}
			}
		}
		
		public function setPageLayoutToOption()
		{
			$main_layout = isset($_GET['main_layout']) ? $_GET['main_layout'] : '';
			if (array_key_exists($main_layout, G5P()->settings()->get_main_layout())) {
				G5P()->options()->setOptions('main_layout', $main_layout);
			}
			
			$sidebar_layout = isset($_GET['sidebar_layout']) ? $_GET['sidebar_layout'] : '';
			if (array_key_exists($sidebar_layout, G5P()->settings()->get_sidebar_layout())) {
				G5P()->options()->setOptions('sidebar_layout', $sidebar_layout);
			}
			
			$content_full_width = isset($_GET['content_full_width']) ? $_GET['content_full_width'] : '';
			if ($content_full_width != '') {
				G5P()->options()->setOptions('content_full_width', $content_full_width);
			}
			
			$remove_content_padding = isset($_GET['remove_content_padding']) ? $_GET['remove_content_padding'] : '';
			if ($remove_content_padding == 'on') {
				G5P()->options()->setOptions('content_padding', array('left' => 0, 'right' => 0, 'top' => 0, 'bottom' => 0));
			}
			
			$feature_post_layout_enable = isset($_GET['feature_post_layout_enable']) ? $_GET['feature_post_layout_enable'] : '';
			if (!empty($feature_post_layout_enable)) {
				G5P()->options()->setOptions('feature_post_layout_enable', $feature_post_layout_enable);
			}
			
			$feature_post_position = isset($_GET['feature_post_position']) ? $_GET['feature_post_position'] : '';
			if (!empty($feature_post_position)) {
				G5P()->options()->setOptions('feature_post_position', $feature_post_position);
			}
			
			$feature_post_layout = isset($_GET['feature_post_layout']) ? $_GET['feature_post_layout'] : '';
			if (!empty($feature_post_layout)) {
				G5P()->options()->setOptions('feature_post_layout', $feature_post_layout);
			}
			
			$feature_post_columns_gutter = isset($_GET['feature_post_columns_gutter']) ? $_GET['feature_post_columns_gutter'] : '';
			if (!empty($feature_post_columns_gutter)) {
				G5P()->options()->setOptions('feature_post_columns_gutter', $feature_post_columns_gutter);
			}
			
			$single_post_layout = isset($_GET['single_post_layout']) ? $_GET['single_post_layout'] : '';
			if (!empty($single_post_layout)) {
				G5P()->options()->setOptions('single_post_layout', $single_post_layout);
			}
			
			$author_info_layout = isset($_GET['author_info_layout']) ? $_GET['author_info_layout'] : '';
			if (!empty($author_info_layout)) {
				G5P()->options()->setOptions('author_info_layout', $author_info_layout);
			}
			
			$single_related_layout = isset($_GET['single_related_layout']) ? $_GET['single_related_layout'] : '';
			if (!empty($single_related_layout)) {
				G5P()->options()->setOptions('single_related_layout', $single_related_layout);
			}
			
			$comment_layout = isset($_GET['comment_layout']) ? $_GET['comment_layout'] : '';
			if (!empty($comment_layout)) {
				G5P()->options()->setOptions('comment_layout', $comment_layout);
			}
		}

        public function editorStyle($config) {
            $fonts = GSF()->core()->fonts()->getFontEnqueue();
            foreach ($fonts['urls'] as $key => $url) {
                $config[] = $url;
            }
            return $config;
        }
		
		public function allowedPostTags()
		{
			global $allowedposttags;
			$allowedposttags['a']['data-hash'] = true;
			$allowedposttags['a']['data-product_id'] = true;
			$allowedposttags['a']['data-original-title'] = true;
			$allowedposttags['a']['aria-describedby'] = true;
			$allowedposttags['a']['data-quantity'] = true;
			$allowedposttags['a']['data-product_sku'] = true;
			$allowedposttags['a']['data-rel'] = true;
			$allowedposttags['a']['data-product-type'] = true;
			$allowedposttags['a']['data-product-id'] = true;
			$allowedposttags['a']['data-toggle'] = true;
			
			$allowedposttags['div']['data-owl-options'] = true;
			$allowedposttags['div']['data-plugin-options'] = true;
			$allowedposttags['div']['data-player'] = true;
			$allowedposttags['div']['data-audio'] = true;
			$allowedposttags['div']['data-title'] = true;
			$allowedposttags['div']['data-animsition-in-class'] = true;
			$allowedposttags['div']['data-animsition-out-class'] = true;
			$allowedposttags['div']['data-animsition-overlay'] = true;
			
			$allowedposttags['textarea']['placeholder'] = true;
			
			$allowedposttags['iframe']['align'] = true;
			$allowedposttags['iframe']['frameborder'] = true;
			$allowedposttags['iframe']['height'] = true;
			$allowedposttags['iframe']['longdesc'] = true;
			$allowedposttags['iframe']['marginheight'] = true;
			$allowedposttags['iframe']['marginwidth'] = true;
			$allowedposttags['iframe']['name'] = true;
			$allowedposttags['iframe']['sandbox'] = true;
			$allowedposttags['iframe']['scrolling'] = true;
			$allowedposttags['iframe']['seamless'] = true;
			$allowedposttags['iframe']['src'] = true;
			$allowedposttags['iframe']['srcdoc'] = true;
			$allowedposttags['iframe']['width'] = true;
			$allowedposttags['iframe']['defer'] = true;
			
			$allowedposttags['input']['accept'] = true;
			$allowedposttags['input']['align'] = true;
			$allowedposttags['input']['alt'] = true;
			$allowedposttags['input']['autocomplete'] = true;
			$allowedposttags['input']['autofocus'] = true;
			$allowedposttags['input']['checked'] = true;
			$allowedposttags['input']['class'] = true;
			$allowedposttags['input']['disabled'] = true;
			$allowedposttags['input']['form'] = true;
			$allowedposttags['input']['formaction'] = true;
			$allowedposttags['input']['formenctype'] = true;
			$allowedposttags['input']['formmethod'] = true;
			$allowedposttags['input']['formnovalidate'] = true;
			$allowedposttags['input']['formtarget'] = true;
			$allowedposttags['input']['height'] = true;
			$allowedposttags['input']['list'] = true;
			$allowedposttags['input']['max'] = true;
			$allowedposttags['input']['maxlength'] = true;
			$allowedposttags['input']['min'] = true;
			$allowedposttags['input']['multiple'] = true;
			$allowedposttags['input']['name'] = true;
			$allowedposttags['input']['pattern'] = true;
			$allowedposttags['input']['placeholder'] = true;
			$allowedposttags['input']['readonly'] = true;
			$allowedposttags['input']['required'] = true;
			$allowedposttags['input']['size'] = true;
			$allowedposttags['input']['src'] = true;
			$allowedposttags['input']['step'] = true;
			$allowedposttags['input']['type'] = true;
			$allowedposttags['input']['value'] = true;
			$allowedposttags['input']['width'] = true;
			$allowedposttags['input']['accesskey'] = true;
			$allowedposttags['input']['class'] = true;
			$allowedposttags['input']['contenteditable'] = true;
			$allowedposttags['input']['contextmenu'] = true;
			$allowedposttags['input']['dir'] = true;
			$allowedposttags['input']['draggable'] = true;
			$allowedposttags['input']['dropzone'] = true;
			$allowedposttags['input']['hidden'] = true;
			$allowedposttags['input']['id'] = true;
			$allowedposttags['input']['lang'] = true;
			$allowedposttags['input']['spellcheck'] = true;
			$allowedposttags['input']['style'] = true;
			$allowedposttags['input']['tabindex'] = true;
			$allowedposttags['input']['title'] = true;
			$allowedposttags['input']['translate'] = true;
			
			$allowedposttags['span']['data-id'] = true;
		}
		
	}
}