<?php
if (!defined('ABSPATH')) {
	exit('Direct script access denied.');
}
if (!class_exists(' G5P_Inc_Settings')) {
	class  G5P_Inc_Settings
	{
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		/**
		 * Get Main Layout
		 *
		 * @param bool $default
		 * @return mixed|void
		 */
		public function get_main_layout($default = false)
		{
			$defaults = array();
			if ($default) {
				$defaults[''] = array(
					'label' => esc_html__('Inherit', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
				);
			}
			$config = apply_filters('gsf_options_main_layout', array(
				'wide'     => array(
					'label' => esc_html__('Wide', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/layout-wide.png'),
				),
				'boxed'    => array(
					'label' => esc_html__('Boxed', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/layout-boxed.png'),
				),
				'framed'   => array(
					'label' => esc_html__('Framed', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/layout-framed.png'),
				),
				'bordered' => array(
					'label' => esc_html__('Bordered', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/layout-bordered.png'),
				)
			));
			
			$config = wp_parse_args($config, $defaults);
			return $config;
		}
		
		/**
		 * Get Sidebar Layout
		 *
		 * @param bool $inherit
		 * @return mixed|void
		 */
		public function get_sidebar_layout($inherit = false)
		{
			$config = apply_filters('gsf_options_sidebar_layout', array(
				'none'  => array(
					'label' => esc_html__('Full Width', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/sidebar-none.png'),
				),
				'left'  => array(
					'label' => esc_html__('Left Sidebar', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/sidebar-left.png'),
				),
				'right' => array(
					'label' => esc_html__('Right Sidebar', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/sidebar-right.png'),
				)
			));
			
			if ($inherit) {
				$config = array(
						'' => array(
							'label' => esc_html__('Inherit', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						)
					) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Sidebar Width
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_sidebar_width($inherit = false)
		{
			$config = apply_filters('gsf_options_sidebar_width', array(
				'small' => esc_html__('Small (1/4)', 'achilles-framework'),
				'large' => esc_html__('Large (1/3)', 'achilles-framework')
			));
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Toggle
		 *
		 * @param bool $inherit
		 * @return array
		 */
		public function get_toggle($inherit = false)
		{
			$config = array(
				'on'  => esc_html__('On', 'achilles-framework'),
				'off' => esc_html__('Off', 'achilles-framework')
			);
			
			if ($inherit) {
				$config = array('' => esc_html__('Inherit', 'achilles-framework')) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Header Customize Nav Left Required
		 *
		 * @return array
		 */
		public function get_header_customize_nav_left_required()
		{
			return apply_filters('gsf_options_header_customize_nav_required', array('header-1', 'header-2'));
		}
		
		/**
		 * Get Header Customize Nav Right Required
		 *
		 * @return array
		 */
		public function get_header_customize_nav_right_required()
		{
			return apply_filters('gsf_options_header_customize_nav_required', array('header-1', 'header-2', 'header-3', 'header-4', 'header-5', 'header-6', 'header-7'));
		}
		
		/**
		 * Get Header Customize Left Required
		 *
		 * @return array
		 */
		public function get_header_customize_left_required()
		{
			return apply_filters('gsf_options_header_customize_nav_required', array('header-1', 'header-2', 'header-5'));
		}
		
		/**
		 * Get Header Customize Right Required
		 *
		 * @return array
		 */
		public function get_header_customize_right_required()
		{
			return apply_filters('gsf_options_header_customize_nav_required', array('header-1', 'header-2', 'header-5'));
		}
		
		/**
		 * Get Search Ajax Post Type
		 *
		 * @return array
		 */
		public function get_search_ajax_popup_post_type()
		{
			
			$output = array(
				'post' => esc_html__('Post', 'achilles-framework'),
				'page' => esc_html__('Page', 'achilles-framework'),
			);
			
			if (class_exists('WooCommerce')) {
				$output['product'] = esc_html__('Product', 'achilles-framework');
			}
			
			
			return apply_filters('gsf_options_get_search_popup_ajax_post_type', $output);
		}
		
		/**
		 * Get Maintenance Mode
		 *
		 * @return array
		 */
		public function get_maintenance_mode()
		{
			return apply_filters('gsf_options_maintenance_mode', array(
				'2' => 'On (Custom Page)',
				'1' => 'On (Standard)',
				'0' => 'Off',
			));
		}
		
		/**
		 * Get Header Layout
		 *
		 * @return array
		 */
		public function get_header_layout()
		{
			return apply_filters('gsf_options_header_layout', array(
				'header-1' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-1.jpg'),
					'label' => esc_html__('Header 1', 'achilles-framework')
				),
				'header-2' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-2.jpg'),
					'label' => esc_html__('Header 2', 'achilles-framework')
				),
				'header-3' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-3.png'),
					'label' => esc_html__('Header 3', 'achilles-framework')
				),
				'header-4' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-4.png'),
					'label' => esc_html__('Header 4', 'achilles-framework')
				),
				'header-5' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-7.png'),
					'label' => esc_html__('Header 5', 'achilles-framework')
				),
				'header-6' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-8.png'),
					'label' => esc_html__('Header 6', 'achilles-framework')
				),
				'header-7' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-9.png'),
					'label' => esc_html__('Header 7', 'achilles-framework')
				),
			));
		}
		
		/**
		 * Get Header Customize
		 *
		 * @return array
		 */
		public function get_header_customize()
		{
			$settings = array(
				'search'          => esc_html__('Search', 'achilles-framework'),
				'social-networks' => esc_html__('Social Networks', 'achilles-framework'),
				'sidebar'         => esc_html__('Sidebar', 'achilles-framework'),
				'custom-html'     => esc_html__('Custom Html', 'achilles-framework'),
				'canvas-sidebar'  => esc_html__('Canvas Sidebar', 'achilles-framework'),
			);
			if (class_exists('WooCommerce')) {
				$settings['shopping-cart'] = esc_html__('Shopping Cart', 'achilles-framework');
			}
			return apply_filters('gsf_options_header_customize', $settings);
		}
		
		/**
		 * Get Header Mobile Layout
		 *
		 * @return array
		 */
		public function get_header_mobile_layout()
		{
			return apply_filters('gsf_options_header_mobile_layout', array(
				'header-1' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-mobile-layout-1.png'),
					'label' => esc_html__('Layout 1', 'achilles-framework')
				),
				'header-2' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-mobile-layout-2.png'),
					'label' => esc_html__('Layout 2', 'achilles-framework')
				),
				'header-3' => array(
					'img'   => G5P()->pluginUrl('assets/images/theme-options/header-mobile-layout-3.png'),
					'label' => esc_html__('Layout 3', 'achilles-framework')
				)
			));
		}
		
		/**
		 * Get Border Layout
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_border_layout($inherit = false)
		{
			$config = apply_filters('gsf_options_border_layout', array(
				'none'      => esc_html__('None', 'achilles-framework'),
				'full'      => esc_html__('Full', 'achilles-framework'),
				'container' => esc_html__('Container', 'achilles-framework')
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Loading Animation
		 *
		 * @return array
		 */
		public function get_loading_animation()
		{
			return apply_filters('gsf_options_loading_animation', array(
				''              => esc_html__('None', 'achilles-framework'),
				'chasing-dots'  => esc_html__('Chasing Dots', 'achilles-framework'),
				'circle'        => esc_html__('Circle', 'achilles-framework'),
				'cube'          => esc_html__('Cube', 'achilles-framework'),
				'double-bounce' => esc_html__('Double Bounce', 'achilles-framework'),
				'fading-circle' => esc_html__('Fading Circle', 'achilles-framework'),
				'folding-cube'  => esc_html__('Folding Cube', 'achilles-framework'),
				'pulse'         => esc_html__('Pulse', 'achilles-framework'),
				'three-bounce'  => esc_html__('Three Bounce', 'achilles-framework'),
				'wave'          => esc_html__('Wave', 'achilles-framework'),
			));
		}
		
		/**
		 * Get Top Drawer Mode
		 *
		 * @return mixed|void
		 */
		public function get_top_drawer_mode()
		{
			return apply_filters('gsf_options_top_drawer_mode', array(
				'hide'   => esc_html__('Hide', 'achilles-framework'),
				'toggle' => esc_html__('Toggle', 'achilles-framework'),
				'show'   => esc_html__('Show', 'achilles-framework')
			));
		}
		
		/**
		 * Get Color Skin default
		 *
		 * @return mixed|void
		 */
		public function &get_color_skin_default()
		{
			$skin_default = array(
				array(
					'skin_id'          => 'skin-light',
					'skin_name'        => esc_html__('Light', 'achilles-framework'),
					'background_color' => '#fff',
					'text_color'       => '#555',
					'text_color_hover' => '#e1757d',
					'heading_color'    => '#252525',
					'disable_color'    => '#acacac',
					'border_color'     => '#ebebeb'
				),
				array(
					'skin_id'          => 'skin-dark',
					'skin_name'        => esc_html__('Dark', 'achilles-framework'),
					'background_color' => '#111111',
					'text_color'       => '#555',
					'text_color_hover' => '#e1757d',
					'heading_color'    => '#fff',
					'disable_color'    => '#acacac',
					'border_color'     => '#ebebeb'
				),
			);
			return $skin_default;
		}
		
		
		/**
		 * Get Color Skin
		 *
		 * @param bool $default
		 * @return array
		 */
		public function get_color_skin($default = false)
		{
			$skins = array();
			if ($default) {
				$skins[] = esc_html__('Inherit', 'achilles-framework');
			}
			$custom_color_skin = G5P()->optionsSkin()->get_color_skin();
			if (is_array($custom_color_skin)) {
				foreach ($custom_color_skin as $key => $value) {
					if (isset($value['skin_name']) && isset($value['skin_id'])) {
						$skins[$value['skin_id']] = $value['skin_name'];
					}
					
				}
			}
			return $skins;
		}
		
		public function getPresetPostType()
		{
			$settings = array(
				'page_404' => array(
					'title' => esc_html__('404 Page', 'achilles-framework')
				),
				'post'     => array(
					'title'  => esc_html__('Blog', 'achilles-framework'),
					'preset' => array(
						'blog'        => array(
							'title' => esc_html__('Blog Listing', 'achilles-framework'),
						),
						'single_blog' => array(
							'title'     => esc_html__('Single Blog', 'achilles-framework'),
							'is_single' => true,
						)
					)
				)
			);
			
			if (class_exists('WooCommerce')) {
				$settings = array_merge($settings, array(
					'product' => array(
						'title'  => esc_html__('Woocommerce', 'achilles-framework'),
						'preset' => array(
							'archive_product' => array(
								'title'      => esc_html__('Product Listing', 'achilles-framework'),
								'category'   => 'product_cat',
								'tag'        => 'product_tag',
								'is_archive' => true,
							),
							'single_product'  => array(
								'title'     => esc_html__('Single Product', 'achilles-framework'),
								'is_single' => true,
							)
						)
					)
				));
			}
			return apply_filters('gsf_options_preset', $settings);
		}
		
		public function get_custom_post_layout_settings()
		{
			$settings = array(
				'search' => array(
					'title' => esc_html__('Search Listing', 'achilles-framework')
				)
			);
			
			return apply_filters('gsf_options_custom_post_layout_settings', $settings);
		}
		
		/**
		 * Get social networks default
		 *
		 * @return array
		 */
		public function get_social_networks_default()
		{
			$social_networks = array(
				array(
					'social_name'  => esc_html__('Facebook', 'achilles-framework'),
					'social_id'    => 'social-facebook',
					'social_icon'  => 'fa fa-facebook',
					'social_link'  => '',
					'social_color' => '#3b5998'
				),
				array(
					'social_name'  => esc_html__('Twitter', 'achilles-framework'),
					'social_id'    => 'social-twitter',
					'social_icon'  => 'fa fa-twitter',
					'social_link'  => '',
					'social_color' => '#1da1f2'
				),
				array(
					'social_name'  => esc_html__('Pinterest', 'achilles-framework'),
					'social_id'    => 'social-pinterest',
					'social_icon'  => 'fa fa-pinterest',
					'social_link'  => '',
					'social_color' => '#bd081c'
				),
				array(
					'social_name'  => esc_html__('Dribbble', 'achilles-framework'),
					'social_id'    => 'social-dribbble',
					'social_icon'  => 'fa fa-dribbble',
					'social_link'  => '',
					'social_color' => '#00b6e3'
				),
				array(
					'social_name'  => esc_html__('LinkedIn', 'achilles-framework'),
					'social_id'    => 'social-linkedIn',
					'social_icon'  => 'fa fa-linkedin',
					'social_link'  => '',
					'social_color' => '#0077b5'
				),
				array(
					'social_name'  => esc_html__('Vimeo', 'achilles-framework'),
					'social_id'    => 'social-vimeo',
					'social_icon'  => 'fa fa-vimeo',
					'social_link'  => '',
					'social_color' => '#1ab7ea'
				),
				array(
					'social_name'  => esc_html__('Tumblr', 'achilles-framework'),
					'social_id'    => 'social-tumblr',
					'social_icon'  => 'fa fa-tumblr',
					'social_link'  => '',
					'social_color' => '#35465c'
				),
				array(
					'social_name'  => esc_html__('Skype', 'achilles-framework'),
					'social_id'    => 'social-skype',
					'social_icon'  => 'fa fa-skype',
					'social_link'  => '',
					'social_color' => '#00aff0'
				),
				array(
					'social_name'  => esc_html__('Google+', 'achilles-framework'),
					'social_id'    => 'social-google-plus',
					'social_icon'  => 'fa fa-google-plus',
					'social_link'  => '',
					'social_color' => '#dd4b39'
				),
				array(
					'social_name'  => esc_html__('Flickr', 'achilles-framework'),
					'social_id'    => 'social-flickr',
					'social_icon'  => 'fa fa-flickr',
					'social_link'  => '',
					'social_color' => '#ff0084'
				),
				array(
					'social_name'  => esc_html__('YouTube', 'achilles-framework'),
					'social_id'    => 'social-youTube',
					'social_icon'  => 'fa fa-youtube',
					'social_link'  => '',
					'social_color' => '#cd201f'
				),
				array(
					'social_name'  => esc_html__('Foursquare', 'achilles-framework'),
					'social_id'    => 'social-foursquare',
					'social_icon'  => 'fa fa-foursquare',
					'social_link'  => '',
					'social_color' => '#f94877'
				),
				array(
					'social_name'  => esc_html__('Instagram', 'achilles-framework'),
					'social_id'    => 'social-instagram',
					'social_icon'  => 'fa fa-instagram',
					'social_link'  => '',
					'social_color' => '#405de6'
				),
				array(
					'social_name'  => esc_html__('GitHub', 'achilles-framework'),
					'social_id'    => 'social-gitHub',
					'social_icon'  => 'fa fa-github',
					'social_link'  => '',
					'social_color' => '#4078c0'
				),
				array(
					'social_name'  => esc_html__('Xing', 'achilles-framework'),
					'social_id'    => 'social-xing',
					'social_icon'  => 'fa fa-xing',
					'social_link'  => '',
					'social_color' => '#026466'
				),
				array(
					'social_name'  => esc_html__('Behance', 'achilles-framework'),
					'social_id'    => 'social-behance',
					'social_icon'  => 'fa fa-behance',
					'social_link'  => '',
					'social_color' => '#1769ff'
				),
				array(
					'social_name'  => esc_html__('Deviantart', 'achilles-framework'),
					'social_id'    => 'social-deviantart',
					'social_icon'  => 'fa fa-deviantart',
					'social_link'  => '',
					'social_color' => '#05cc47'
				),
				array(
					'social_name'  => esc_html__('Sound Cloud', 'achilles-framework'),
					'social_id'    => 'social-soundCloud',
					'social_icon'  => 'fa fa-soundcloud',
					'social_link'  => '',
					'social_color' => '#ff8800'
				),
				array(
					'social_name'  => esc_html__('Yelp', 'achilles-framework'),
					'social_id'    => 'social-yelp',
					'social_icon'  => 'fa fa-yelp',
					'social_link'  => '',
					'social_color' => '#af0606'
				),
				array(
					'social_name'  => esc_html__('RSS Feed', 'achilles-framework'),
					'social_id'    => 'social-rss',
					'social_icon'  => 'fa fa-rss',
					'social_link'  => '',
					'social_color' => '#f26522'
				),
				array(
					'social_name'  => esc_html__('VK', 'achilles-framework'),
					'social_id'    => 'social-vk',
					'social_icon'  => 'fa fa-vk',
					'social_link'  => '',
					'social_color' => '#45668e'
				),
				array(
					'social_name'  => esc_html__('Email', 'achilles-framework'),
					'social_id'    => 'social-email',
					'social_icon'  => 'fa fa-envelope',
					'social_link'  => '',
					'social_color' => '#4285f4'
				),
			
			);
			return $social_networks;
		}
		
		public function get_social_networks()
		{
			$social_networks = G5P()->options()->get_social_networks();
			$options = array();
			if (is_array($social_networks)) {
				foreach ($social_networks as $social_network) {
					$options[$social_network['social_id']] = $social_network['social_name'];
				}
			}
			return $options;
		}
		
		/**
		 * Get social share
		 *
		 * @return array
		 */
		public function get_social_share()
		{
			$social_share = array(
				'facebook'  => esc_html__('Facebook', 'achilles-framework'),
				'twitter'   => esc_html__('Twitter', 'achilles-framework'),
				'pinterest' => esc_html__('Pinterest', 'achilles-framework'),
				'google'    => esc_html__('Google +', 'achilles-framework'),
				'linkedin'  => esc_html__('Linkedin', 'achilles-framework'),
				'tumblr'    => esc_html__('Tumblr', 'achilles-framework'),
				'email'     => esc_html__('Email', 'achilles-framework'),
				'telegram'  => esc_html__('Telegram', 'achilles-framework'),
				'whatsapp'  => esc_html__('WhatsApp', 'achilles-framework'),
			);
			return $social_share;
		}
		
		/**
		 * Get Feature Post Position
		 * @param bool $inherit
		 */
		public function get_feature_post_position($inherit = false)
		{
			$config = apply_filters('gsf_options_feature_post_position', array(
				'inside-content' => esc_html__('Inside Content', 'achilles-framework'),
				'before-content' => esc_html__('Before Content', 'achilles-framework'),
			));
			if ($inherit) {
				$config = array(
						'' => array(
							'label' => esc_html__('Inherit', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						),
					) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Feature Post Layout
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_feature_post_layout($inherit = false)
		{
			$config = apply_filters('gsf_options_feature_post_layout', array(
				'feature-1'  => array(
					'label' => esc_html__('Feature 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-1.png'),
				),
				'feature-2'  => array(
					'label' => esc_html__('Feature 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-2.png'),
				),
				'feature-3'  => array(
					'label' => esc_html__('Feature 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-3.png'),
				),
				'feature-4'  => array(
					'label' => esc_html__('Feature 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-4.png'),
				),
				'feature-5'  => array(
					'label' => esc_html__('Feature 5', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-5.png'),
				),
				'feature-6'  => array(
					'label' => esc_html__('Feature 6', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-6.png'),
				),
				'feature-7'  => array(
					'label' => esc_html__('Feature 7', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-7.jpg'),
				),
				'feature-8'  => array(
					'label' => esc_html__('Feature 8', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-8.png'),
				),
				'feature-9'  => array(
					'label' => esc_html__('Feature 9', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-9.png'),
				),
				'feature-10' => array(
					'label' => esc_html__('Feature 10', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/feature-10.png'),
				),
			));
			if ($inherit) {
				$config = array(
						'' => array(
							'label' => esc_html__('Inherit', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						),
					) + $config;
			}
			return $config;
		}
		
		/**
		 * Get Post Layout
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_post_layout($inherit = false)
		{
			$config = apply_filters('gsf_options_post_layout', array(
				'large-image'    => array(
					'label' => esc_html__('Large Image', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-large-image-2.jpg'),
				),
				'grid-image'     => array(
					'label' => esc_html__('Grid Image', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-grid-3.png'),
				),
				'grid-image-2'   => array(
					'label' => esc_html__('Grid Image 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-grid-4.png'),
				),
				'grid-image-3'   => array(
					'label' => esc_html__('Grid Image 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-grid-5.png'),
				),
				'masonry-image'  => array(
					'label' => esc_html__('Masonry Image', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-masonry-2.png'),
				),
				'medium-image-1' => array(
					'label' => esc_html__('Medium Image 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-6.png'),
				),
				'medium-image-2' => array(
					'label' => esc_html__('Medium Image 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-7.png'),
				),
				'medium-image-3' => array(
					'label' => esc_html__('Medium Image 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-8.png'),
				),
				'medium-image-4' => array(
					'label' => esc_html__('Medium Image 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-5.jpg'),
				),
				'zigzac-image'   => array(
					'label' => esc_html__('Zigzac Image', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-zigzac.png'),
				),
			));
			if ($inherit) {
				$config = array(
						'' => array(
							'label' => esc_html__('Inherit', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						),
					) + $config;
			}
			return $config;
		}
		
		public function get_single_post_layout($inherit = false)
		{
			$config = apply_filters('gsf_options_single_post_layout', array(
				'layout-1' => array(
					'label' => esc_html__('Layout 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-1.jpg'),
				),
				'layout-2' => array(
					'label' => esc_html__('Layout 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-2.jpg'),
				),
				'layout-3' => array(
					'label' => esc_html__('Layout 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-3.jpg'),
				),
				'layout-4' => array(
					'label' => esc_html__('Layout 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-4.jpg'),
				),
				'layout-5' => array(
					'label' => esc_html__('Layout 5', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-5.jpg'),
				),
				'layout-6' => array(
					'label' => esc_html__('Layout 6', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-6.jpg'),
				),
				'layout-7' => array(
					'label' => esc_html__('Layout 7', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-7.jpg'),
				),
				'layout-8' => array(
					'label' => esc_html__('Layout 8', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-8.jpg'),
				),
				'layout-9' => array(
					'label' => esc_html__('Layout 9', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/post-layout-9.jpg'),
				),
			
			));
			if ($inherit) {
				$config = array(
						'' => array(
							'label' => esc_html__('Inherit', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						),
					) + $config;
			}
			return $config;
		}
		
		public function get_author_info_layout()
		{
			$author_info = array(
				'author-layout-1' => array(
					'label' => esc_html__('Layout 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/author-layout-1.jpg'),
				),
				'author-layout-2' => array(
					'label' => esc_html__('Layout 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/author-layout-2.jpg'),
				),
				'author-layout-3' => array(
					'label' => esc_html__('Layout 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/author-layout-3.jpg'),
				),
			);
			return $author_info;
		}
		
		/**
		 * Get Single Post Ordinal
		 *
		 * @return array
		 */
		
		public function get_single_post_ordinal()
		{
			$single_post_ordinal = array(
				'related-post'  => esc_html__('Relate Post', 'achilles-framework'),
				'content-block' => esc_html__('Content Block', 'achilles-framework'),
				'comment'       => esc_html__('Comment', 'achilles-framework'),
			);
			return $single_post_ordinal;
		}
		
		public function get_related_post_layout()
		{
			$related_post = array(
				'related-post-layout-1' => array(
					'label' => esc_html__('Layout 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/related-post-layout-1.jpg'),
				),
				'related-post-layout-2' => array(
					'label' => esc_html__('Layout 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/related-post-layout-2.jpg'),
				),
				'related-post-layout-3' => array(
					'label' => esc_html__('Layout 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/related-post-layout-3.jpg'),
				),
			);
			return $related_post;
		}
		
		public function get_comment_layout()
		{
			$comment_layout = array(
				'comment-layout-1' => array(
					'label' => esc_html__('Layout 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/comment-layout-1.jpg'),
				),
				'comment-layout-2' => array(
					'label' => esc_html__('Layout 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/comment-layout-2.jpg'),
				),
			);
			return $comment_layout;
		}
		
		/**
		 * Get Post Columns
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_post_columns($inherit = false)
		{
			$config = apply_filters('gsf_options_post_columns', array(
				'1' => '1',
				'2' => '2',
				'3' => '3',
				'4' => '4',
				'6' => '6'
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
		}
		
		/**
		 * Get Post Columns Gap
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_post_columns_gutter($inherit = false)
		{
			$config = apply_filters('gsf_options_post_columns_gutter', array(
				'none' => esc_html__('None', 'achilles-framework'),
				'10'   => '10px',
				'20'   => '20px',
				'30'   => '30px',
				'40'   => '40px',
				'50'   => '50px'
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
		}
		
		/**
		 * Get Post Paging Mode
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_post_paging_mode($inherit = false)
		{
			$config = apply_filters('gsf_options_post_paging_mode', array(
				'pagination'      => esc_html__('Pagination', 'achilles-framework'),
				'pagination-ajax' => esc_html__('Ajax - Pagination', 'achilles-framework'),
				'next-prev'       => esc_html__('Ajax - Next Prev', 'achilles-framework'),
				'load-more'       => esc_html__('Ajax - Load More', 'achilles-framework'),
				'infinite-scroll' => esc_html__('Ajax - Infinite Scroll', 'achilles-framework')
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
		}
		
		public function get_post_paging_small_mode($inherit = false)
		{
			$config = apply_filters('gsf_options_post_paging_small_mode', array(
				'none'            => esc_html__('None', 'achilles-framework'),
				'pagination-ajax' => esc_html__('Ajax - Pagination', 'achilles-framework'),
				'next-prev'       => esc_html__('Ajax - Next Prev', 'achilles-framework'),
				'load-more'       => esc_html__('Ajax - Load More', 'achilles-framework'),
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
		}
		
		/**
		 * Get Animation
		 *
		 * @param $inherit
		 * @return array|mixed|void
		 */
		public function get_animation($inherit = false)
		{
			$config = apply_filters('gsf_options_animation', array(
				'none'          => esc_html__('None', 'achilles-framework'),
				'top-to-bottom' => esc_html__('Top to bottom', 'achilles-framework'),
				'bottom-to-top' => esc_html__('Bottom to top', 'achilles-framework'),
				'left-to-right' => esc_html__('Left to right', 'achilles-framework'),
				'right-to-left' => esc_html__('Right to left', 'achilles-framework'),
				'appear'        => esc_html__('Appear from center', 'achilles-framework')
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
		}
		
		/**
		 * Get Related Post Algorithm
		 *
		 * @param bool $inherit
		 * @return array|mixed|void
		 */
		public function get_related_post_algorithm($inherit = false)
		{
			$config = apply_filters('gsf_options_related_post_algorithm', array(
				'cat'            => esc_html__('by Category', 'achilles-framework'),
				'tag'            => esc_html__('by Tag', 'achilles-framework'),
				'author'         => esc_html__('by Author', 'achilles-framework'),
				'cat-tag'        => esc_html__('by Category & Tag', 'achilles-framework'),
				'cat-tag-author' => esc_html__('by Category & Tag & Author', 'achilles-framework'),
				'random'         => esc_html__('Randomly', 'achilles-framework')
			));
			
			if ($inherit) {
				$config = array(
						'' => esc_html__('Inherit', 'achilles-framework')
					) + $config;
			}
			
			return $config;
			
		}
		
	}
}