<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('G5P_Inc_ShortCode')) {
	class G5P_Inc_ShortCode
	{
		private static $_instance;
		
		public static function getInstance()
		{
			if (self::$_instance == NULL) {
				self::$_instance = new self();
			}
			
			return self::$_instance;
		}
		
		public function init()
		{
			$this->includes();
			// Auto Loader Class
			spl_autoload_register(array($this, 'autoload_class_file'));
			
			// vc learn map
			add_action('vc_before_mapping', array($this, 'vc_lean_map'));
			
		}
		
		/**
		 * Auto Loader Class
		 *
		 * @param $class_name
		 */
		public function autoload_class_file($class)
		{
			
			$file_name = preg_replace('/^WPBakeryShortCode_gsf_/', '', $class);
			if ($file_name !== $class) {
				$file_name = strtolower($file_name);
				$file_name = str_replace('_', '-', $file_name);
				G5P()->loadFile(G5P()->pluginDir("shortcodes/{$file_name}/{$file_name}.php"));
			}
		}
		
		public function includes()
		{
			G5P()->loadFile(G5P()->pluginDir('shortcodes/shortcode-base.class.php'));
		}
		
		/**
		 * Get Shortcodes category name
		 *
		 * @return string
		 */
		public function get_category_name()
		{
			$current_theme = wp_get_theme();
			return $current_theme['Name'] . ' Shortcodes';
		}
		
		/**
		 * Get Shortcodes Post category name
		 *
		 * @return string
		 */
		public function get_category_post_name()
		{
			return 'Shortcode Posts';
		}
		
		/**
		 * Get List Shortcodes
		 *
		 * @return mixed|void
		 */
		private function get_shortcodes()
		{
			return apply_filters('gsf_shorcodes', array(
				'gsf_banner',
				'gsf_breadcrumbs',
				'gsf_button',
				'gsf_gallery',
				'gsf_google_map',
				'gsf_heading',
				'gsf_menu_column',
				'gsf_new_magazine',
				'gsf_page_title',
				'gsf_social_networks',
				'gsf_space',
				'gsf_video',
				'gsf_post_grid_1',
				'gsf_post_large_1',
				'gsf_post_large_2',
				'gsf_post_large_3',
				'gsf_post_large_4',
				'gsf_post_large_5',
				'gsf_post_large_6',
				'gsf_post_list_1',
				'gsf_post_list_2',
				'gsf_post_list_3',
				'gsf_post_medium_1',
				'gsf_post_medium_2',
				'gsf_post_medium_3',
				'gsf_post_medium_4',
				'gsf_post_medium_5',
				'gsf_post_mix_1',
				'gsf_post_mix_2',
				'gsf_post_mix_3',
				'gsf_post_mix_4',
				'gsf_post_mix_5',
				'gsf_post_mix_6',
				'gsf_post_mix_7',
				'gsf_post_mix_8',
				'gsf_post_mix_9',
				'gsf_post_mix_10',
				'gsf_post_mix_11',
				'gsf_post_mix_12',
				'gsf_post_mix_13',
				'gsf_post_mix_14',
				'gsf_post_mix_15',
				'gsf_post_mix_16',
				'gsf_post_mix_17',
				'gsf_post_mix_18',
				'gsf_post_mix_19',
				'gsf_post_mix_20',
				'gsf_post_mix_21',
				'gsf_post_mix_22',
				'gsf_post_mix_23',
				'gsf_post_mix_24',
				'gsf_post_mix_25',
				'gsf_post_small_1',
				'gsf_post_tall_1',
				'gsf_post_tall_2',
				'gsf_post_tall_3',
				'gsf_post_tall_4',
				'gsf_posts_carousel',
			
			));
		}
		
		public function vc_lean_map()
		{
			$shorcodes = $this->get_shortcodes();
			foreach ($shorcodes as $key) {
				$directory = preg_replace('/^gsf_/', '', $key);
				vc_lean_map($key, null, G5P()->pluginDir('shortcodes/' . str_replace('_', '-', $directory) . '/config.php'));
			}
		}
		
		/**
		 * Get Setting Icon Font
		 *
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_icon_font($args = array())
		{
			$default = array(
				'type'        => 'gsf_icon_picker',
				'heading'     => esc_html__('Icon', 'achilles-framework'),
				'param_name'  => 'icon_font',
				'value'       => '',
				'description' => esc_html__('Select icon from library.', 'achilles-framework')
			);
			
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * Animation Style
		 *
		 * @param bool $label
		 * @return array
		 */
		public function vc_map_add_css_animation($label = true)
		{
			$data = array(
				'type'        => 'animation_style',
				'heading'     => esc_html__('CSS Animation', 'achilles-framework'),
				'param_name'  => 'css_animation',
				'admin_label' => $label,
				'value'       => '',
				'settings'    => array(
					'type'   => 'in',
					'custom' => array(
						array(
							'label'  => esc_html__('Default', 'achilles-framework'),
							'values' => array(
								esc_html__('Top to bottom', 'achilles-framework')      => 'top-to-bottom',
								esc_html__('Bottom to top', 'achilles-framework')      => 'bottom-to-top',
								esc_html__('Left to right', 'achilles-framework')      => 'left-to-right',
								esc_html__('Right to left', 'achilles-framework')      => 'right-to-left',
								esc_html__('Appear from center', 'achilles-framework') => 'appear',
							),
						),
					),
				),
				'description' => esc_html__('Select type of animation for element to be animated when it enters the browsers viewport (Note: works only in modern browsers).', 'achilles-framework'),
				'group'       => esc_html__('Animation', 'achilles-framework')
			);
			return apply_filters('vc_map_add_css_animation', $data, $label);
		}
		
		
		/**
		 * Animation Duration
		 *
		 * @return array
		 */
		public function vc_map_add_animation_duration()
		{
			return array(
				'type'        => 'textfield',
				'heading'     => esc_html__('Animation Duration', 'achilles-framework'),
				'param_name'  => 'animation_duration',
				'value'       => '',
				'description' => wp_kses_post(__('Duration in seconds. You can use decimal points in the value. Use this field to specify the amount of time the animation plays. <em>The default value depends on the animation, leave blank to use the default.</em>', 'achilles-framework')),
				'group'       => esc_html__('Animation', 'achilles-framework')
			);
		}
		
		/**
		 * Animation Delay
		 *
		 * @return array
		 */
		public function vc_map_add_animation_delay()
		{
			return array(
				'type'        => 'textfield',
				'heading'     => esc_html__('Animation Delay', 'achilles-framework'),
				'param_name'  => 'animation_delay',
				'value'       => '',
				'description' => esc_html__('Delay in seconds. You can use decimal points in the value. Use this field to delay the animation for a few seconds, this is helpful if you want to chain different effects one after another above the fold.', 'achilles-framework'),
				'group'       => esc_html__('Animation', 'achilles-framework')
			);
		}
		
		
		/**
		 * Extra Class
		 *
		 * @return array
		 */
		public function vc_map_add_extra_class()
		{
			$args = array(
				'type'        => 'gsf_selectize',
				'heading'     => esc_html__('Extra class name', 'achilles-framework'),
				'param_name'  => 'el_class',
				'tags'        => true,
				'std'         => '',
				'description' => esc_html__('Style particular content element differently - add a class name and refer to it in custom CSS.', 'achilles-framework'),
			);
			$extra_class = &G5P()->helper()->get_extra_class();
			if (is_array($extra_class) && sizeof($extra_class) > 0) {
				$args['value'] = $extra_class;
			}
			return $args;
		}
		
		/**
		 * Design Options
		 *
		 * @return array
		 */
		public function vc_map_add_css_editor()
		{
			return array(
				'type'       => 'css_editor',
				'heading'    => esc_html__('CSS box', 'achilles-framework'),
				'param_name' => 'css',
				'group'      => esc_html__('Design Options', 'achilles-framework'),
			);
		}
		
		public function vc_map_add_responsive()
		{
			return array(
				'type'        => 'gsf_responsive',
				'heading'     => esc_html__('Responsive', 'achilles-framework'),
				'param_name'  => 'responsive',
				'group'       => esc_html__('Responsive Options', 'achilles-framework'),
				'description' => esc_html__('Adjust column for different screen sizes. Control visibility settings.', 'achilles-framework'),
			);
		}
		
		public function vc_map_add_color_skin($args = array())
		{
			$default = array(
				'type'        => 'dropdown',
				'heading'     => esc_html__('Color Skin', 'achilles-framework'),
				'param_name'  => 'color_skin',
				'description' => esc_html__('Select color skin.', 'achilles-framework'),
				'value'       => $this->get_color_skin(true),
				'std'         => '',
				'admin_label' => true,
			
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * Get Color Skin
		 *
		 * @param bool $default
		 * @return array
		 */
		public function get_color_skin($default = false)
		{
			$skins = array();
			if ($default) {
				$skins[esc_html__('Inherit', 'achilles-framework')] = '';
			}
			$custom_color_skin = G5P()->optionsSkin()->get_color_skin();
			if (is_array($custom_color_skin)) {
				foreach ($custom_color_skin as $key => $value) {
					if (isset($value['skin_name']) && isset($value['skin_id'])) {
						$skins[$value['skin_name']] = $value['skin_id'];
					}
					
				}
			}
			return $skins;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_narrow_category($args = array())
		{
			$category = array();
			$categories = get_categories(array('hide_empty' => '1'));
			if (is_array($categories)) {
				foreach ($categories as $cat) {
					$category[$cat->name] = $cat->slug;
				}
			}
			$default = array(
				'type'        => 'gsf_selectize',
				'heading'     => esc_html__('Narrow Category', 'achilles-framework'),
				'param_name'  => 'category',
				'value'       => $category,
				'multiple'    => true,
				'description' => esc_html__('Enter categories by names to narrow output (Note: only listed categories will be displayed, divide categories with linebreak (Enter)).', 'achilles-framework'),
				'std'         => ''
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_narrow_tag($args = array())
		{
			$tag = array();
			$tags = get_tags(array('hide_empty' => '1'));
			if (is_array($tags)) {
				foreach ($tags as $tg) {
					$tag[$tg->name] = $tg->slug;
				}
			}
			$default = array(
				'type'        => 'gsf_selectize',
				'heading'     => esc_html__('Narrow Tag', 'achilles-framework'),
				'param_name'  => 'tag',
				'value'       => $tag,
				'multiple'    => true,
				'description' => esc_html__('Enter tags by names to narrow output).', 'achilles-framework'),
				'std'         => ''
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $array
		 * @return array
		 */
		public function switch_array_key_value($array = array())
		{
			$result = array();
			foreach ($array as $key => $value) {
				$result[$value] = $key;
			}
			return $result;
		}
		
		/**
		 * @return array
		 */
		public function get_toggle()
		{
			return array(
				esc_html__('On', 'achilles-framework')  => '1',
				esc_html__('Off', 'achilles-framework') => '0'
			);
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_sub_title($args = array())
		{
			$default = array(
				'type'       => 'textfield',
				'heading'    => esc_html__('Sub Title', 'achilles-framework'),
				'param_name' => 'sub_title',
				'value'      => base64_encode(''),
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_title($args = array())
		{
			$default = array(
				'type'       => 'textfield',
				'heading'    => esc_html__('Title', 'achilles-framework'),
				'param_name' => 'title',
				'value'      => base64_encode(''),
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_heading_border_bottom_width($args = array())
		{
			$default = array(
				'type'             => 'gsf_button_set',
				'heading'          => esc_html__('Border Bottom Width', 'achilles-framework'),
				'param_name'       => 'border_bottom_width',
				'value'            => array(
					'1px' => '1px',
					'2px' => '2px'
				),
				'edit_field_class' => 'vc_col-sm-6 vc_column',
				'std'              => '1px'
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_icon_shape($args = array())
		{
			$default = array(
				'type'             => 'gsf_button_set',
				'heading'          => esc_html__('Icon Shape', 'achilles-framework'),
				'param_name'       => 'icon_shape',
				'value'            => array(
					esc_html__('Classic', 'achilles-framework') => 'icon-classic',
					esc_html__('Circle', 'achilles-framework')  => 'icon-circle',
				),
				'edit_field_class' => 'vc_col-sm-6 vc_column'
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_pagination($args = array())
		{
			$default = array(
				'type'             => 'gsf_switch',
				'heading'          => esc_html__('Show pagination control', 'achilles-framework'),
				'param_name'       => 'dots',
				'std'              => '',
				'edit_field_class' => 'vc_col-sm-6 vc_column',
				'group'            => esc_html__('Slider Options', 'achilles-framework'),
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_navigation($args = array())
		{
			$default = array(
				'type'             => 'gsf_switch',
				'heading'          => esc_html__('Show navigation control', 'achilles-framework'),
				'param_name'       => 'nav',
				'std'              => 'on',
				'edit_field_class' => 'vc_col-sm-6 vc_column',
				'group'            => esc_html__('Slider Options', 'achilles-framework'),
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_autoplay_enable($args = array())
		{
			$default = array(
				'type'       => 'gsf_switch',
				'heading'    => esc_html__('Autoplay Enable', 'april-framework'),
				'param_name' => 'autoplay',
				'std'        => '',
				
				'edit_field_class' => 'vc_col-sm-6 vc_column'
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		
		/**
		 * @param array $args
		 * @return array
		 */
		public function vc_map_add_autoplay_timeout($args = array())
		{
			$default = array(
				'type'             => 'gsf_number',
				'heading'          => esc_html__('Autoplay Timeout', 'april-framework'),
				'param_name'       => 'autoplay_timeout',
				'std'              => '5000',
				'edit_field_class' => 'vc_col-sm-6 vc_column',
				'dependency'       => array('element' => 'autoplay', 'value' => 'on')
			);
			$default = array_merge($default, $args);
			return $default;
		}
		
		
		/**
		 * @return array
		 */
		public function get_heading_option()
		{
			return array(
				array(
					'type'             => 'gsf_switch',
					'heading'          => esc_html__('Include Heading', 'achilles-framework'),
					'param_name'       => 'include_heading',
					'edit_field_class' => 'vc_col-sm-6 vc_column',
					'std'              => 'on'
				),
				$this->vc_map_add_sub_title(
					array(
						'dependency' => array('element' => 'include_heading', 'value' => 'on'),
						'group'      => esc_html__('Heading Options', 'achilles-framework')
					)
				),
				$this->vc_map_add_title(
					array(
						'dependency' => array('element' => 'include_heading', 'value' => 'on'),
						'group'      => esc_html__('Heading Options', 'achilles-framework')
					)
				),
				$this->vc_map_add_heading_border_bottom_width(
					array(
						'dependency' => array('element' => 'include_heading', 'value' => 'on'),
						'group'      => esc_html__('Heading Options', 'achilles-framework')
					)
				),
				$this->vc_map_add_icon_font(
					array(
						'edit_field_class' => 'vc_col-sm-6 vc_column',
						'dependency'       => array('element' => 'include_heading', 'value' => 'on'),
						'group'            => esc_html__('Heading Options', 'achilles-framework')
					)
				),
				$this->vc_map_add_icon_shape(
					array(
						'dependency' => array('element' => 'icon_font', 'value_not_equal_to' => array('')),
						'group'      => esc_html__('Heading Options', 'achilles-framework')
					)
				),
			);
		}
		
		/**
		 * @return array
		 */
		public function get_post_filter()
		{
			return array(
				$this->vc_map_add_narrow_category(array(
					'group' => esc_html__('Posts Filter', 'achilles-framework')
				)),
				$this->vc_map_add_narrow_tag(array(
					'group' => esc_html__('Posts Filter', 'achilles-framework')
				)),
				array(
					'type'        => 'autocomplete',
					'heading'     => esc_html__('Narrow Post', 'achilles-framework'),
					'param_name'  => 'ids',
					'settings'    => array(
						'multiple'       => true,
						//'sortable' => true,
						'unique_values'  => true,
						'display_inline' => true
					),
					'save_always' => true,
					'group'       => esc_html__('Posts Filter', 'achilles-framework'),
					'description' => esc_html__('Enter List of Posts', 'achilles-framework'),
				),
				array(
					'type'        => 'dropdown',
					'heading'     => esc_html__('Order by', 'achilles-framework'),
					'param_name'  => 'orderby',
					'value'       => array(
						esc_html__('Date', 'achilles-framework')                                                                         => 'date',
						esc_html__('Order by post ID', 'achilles-framework')                                                             => 'ID',
						esc_html__('Author', 'achilles-framework')                                                                       => 'author',
						esc_html__('Title', 'achilles-framework')                                                                        => 'title',
						esc_html__('Last modified date', 'achilles-framework')                                                           => 'modified',
						esc_html__('Post/page parent ID', 'achilles-framework')                                                          => 'parent',
						esc_html__('Number of comments', 'achilles-framework')                                                           => 'comment_count',
						esc_html__('Number of Views ( Install and active plugin Post Views Counter is required )', 'achilles-framework') => 'post_views',
						esc_html__('Menu order/Page Order', 'achilles-framework')                                                        => 'menu_order',
						esc_html__('Meta value', 'achilles-framework')                                                                   => 'meta_value',
						esc_html__('Meta value number', 'achilles-framework')                                                            => 'meta_value_num',
						esc_html__('Random order', 'achilles-framework')                                                                 => 'rand',
					),
					'group'       => esc_html__('Posts Filter', 'achilles-framework'),
					'description' => esc_html__('Select order type. If "Meta value" or "Meta value Number" is chosen then meta key is required.', 'achilles-framework')
				),
				array(
					'type'       => 'dropdown',
					'heading'    => esc_html__('Time Filter', 'achilles-framework'),
					'param_name' => 'time_filter',
					'value'      => array(
						esc_html__('No Filter', 'achilles-framework')               => 'none',
						esc_html__('Today Posts', 'achilles-framework')             => 'today',
						esc_html__('Today + Yesterday Posts', 'achilles-framework') => 'yesterday',
						esc_html__('This Week Posts', 'achilles-framework')         => 'week',
						esc_html__('This Month Posts', 'achilles-framework')        => 'month',
						esc_html__('This Year Posts', 'achilles-framework')         => 'year'
					),
					'group'      => esc_html__('Posts Filter', 'achilles-framework')
				),
				array(
					'type'        => 'gsf_button_set',
					'heading'     => esc_html__('Sorting', 'achilles-framework'),
					'param_name'  => 'order',
					'value'       => array(
						esc_html__('Descending', 'achilles-framework') => 'DESC',
						esc_html__('Ascending', 'achilles-framework')  => 'ASC',
					),
					'std'         => 'DESC',
					'group'       => esc_html__('Posts Filter', 'achilles-framework'),
					'description' => esc_html__('Select sorting order.', 'achilles-framework'),
				),
				
				array(
					'type'        => 'textfield',
					'heading'     => esc_html__('Meta key', 'achilles-framework'),
					'param_name'  => 'meta_key',
					'description' => esc_html__('Input meta key for grid ordering.', 'achilles-framework'),
					'group'       => esc_html__('Posts Filter', 'achilles-framework'),
					'dependency'  => array(
						'element' => 'orderby',
						'value'   => array('meta_value', 'meta_value_num'),
					),
				)
			);
		}
		
		public function get_post_carousel_layout($inherit = false)
		{
			$config = apply_filters('gsf_post_layout', array(
				'grid-1'   => array(
					'label' => esc_html__('Grid Image 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-grid.jpg'),
				),
				'large-2'  => array(
					'label' => esc_html__('Large Image 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-large-image-2.jpg'),
				),
				'large-4'  => array(
					'label' => esc_html__('Large Image 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-large-image-4.png'),
				),
				'large-5'  => array(
					'label' => esc_html__('Large Image 5', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-large-image-5.png'),
				),
				'large-6'  => array(
					'label' => esc_html__('Large Image 6', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-large-image-6.jpg'),
				),
				'list-1'   => array(
					'label' => esc_html__('List 1', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-list-1.jpg'),
				),
				'list-2'   => array(
					'label' => esc_html__('List 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-list-2.jpg'),
				),
				'medium-2' => array(
					'label' => esc_html__('Medium Image 2', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-2.jpg'),
				),
				'medium-3' => array(
					'label' => esc_html__('Medium Image 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-3.jpg'),
				),
				'medium-4' => array(
					'label' => esc_html__('Medium Image 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-4.jpg'),
				),
				'medium-5' => array(
					'label' => esc_html__('Medium Image 5', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-medium-image-5.jpg'),
				),
				'tall-3'   => array(
					'label' => esc_html__('Tall Image 3', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-tall-3.jpg'),
				),
				'tall-4'   => array(
					'label' => esc_html__('Tall Image 4', 'achilles-framework'),
					'img'   => G5P()->pluginUrl('assets/images/theme-options/blog-tall-4.jpg'),
				),
			
			
			));
			if ($inherit) {
				$config = array(
						'-1' => array(
							'label' => esc_html__('Default', 'achilles-framework'),
							'img'   => G5P()->pluginUrl('assets/images/theme-options/default.png'),
						),
					) + $config;
			}
			return $config;
		}
	}
}