<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('G5P_ShortCode_Base')) {
	abstract class G5P_ShortCode_Base extends WPBakeryShortCode
	{
		/**
		 * Find html template for shortcode output.
		 */
		protected function findShortcodeTemplate()
		{
			// Check template path in shortcode's mapping settings
			if (!empty($this->settings['html_template']) && is_file($this->settings('html_template'))) {
				return $this->setTemplate($this->settings['html_template']);
			}
			// Check template in theme directory
			$user_template = vc_shortcodes_theme_templates_dir($this->getFileName() . '.php');
			if (is_file($user_template)) {
				return $this->setTemplate($user_template);
			}
			$template_name = preg_replace('/^gsf_/', '', $this->getFileName());
			$template = G5P()->pluginDir('shortcodes/' . str_replace('_', '-', $template_name) . '/template.php');
			// Check default place
			if (is_file($template)) {
				return $this->setTemplate($template);
			}

			return '';
		}

		/**
		 * Get param value by providing key
		 *
		 * @param $key
		 *
		 * @since 4.4
		 * @return array|bool
		 */
		public function getParamData($key)
		{
			return WPBMap::getParam($this->shortcode, $key);
		}


		/**
		 * @param $font_container
		 * @return array
		 */
		public function get_font_container_attributes($font_container)
		{
			$attributes = array();
			$font_container_obj = new Vc_Font_Container();
			$font_container_field = $this->getParamData( 'font_container' );
			$font_container_field_settings = isset( $font_container_field['settings'], $font_container_field['settings']['fields'] ) ? $font_container_field['settings']['fields'] : array();
			$font_container_data = $font_container_obj->_vc_font_container_parse_attributes( $font_container_field_settings, $font_container );
			if (!empty($font_container_data) && isset($font_container_data['values'])) {
				foreach ($font_container_data['values'] as $key => $value) {
					if ('tag' !== $key && strlen($value)) {
						if (preg_match('/description/', $key)) {
							continue;
						}
						if ('font_size' === $key) {
							$value = preg_replace('/\s+/', '', $value);
							$pattern = '/^(\d*(?:\.\d+)?)\s*(px|\%|in|cm|mm|em|rem|ex|pt|pc|vw|vh|vmin|vmax)?$/';
							$regexr = preg_match($pattern, $value, $matches);
							$value = isset($matches[1]) ? (float)$matches[1] : (float)$value;
							$unit = isset($matches[2]) ? $matches[2] : 'px';
							$value = $value . $unit;
						}
						if('text_align' === $key) {
							$value = 'text-' . $value;
						}
						if (strlen($value) > 0) {
							$attributes[] = $value;
						}
					}
				}
			}
			return $attributes;
		}

		public function get_time_filter_query($time_filter = null) {
			$date_query = array();

			switch ( $time_filter ) {
				// Today posts
				case 'today':
					$date_query = array(
						array(
							'after' => '1 day ago', // should not escaped because will be passed to WP_Query
						),
					);
					break;
				// Today + Yesterday posts
				case 'yesterday':
					$date_query = array(
						array(
							'after' => '2 day ago', // should not escaped because will be passed to WP_Query
						),
					);
					break;
				// Week posts
				case 'week':
					$date_query = array(
						array(
							'after' => '1 week ago', // should not escaped because will be passed to WP_Query
						),
					);
					break;
				// Month posts
				case 'month':
					$date_query = array(
						array(
							'after' => '1 month ago', // should not escaped because will be passed to WP_Query
						),
					);
					break;
				// Year posts
				case 'year':
					$date_query = array(
						array(
							'after' => '1 year ago', // should not escaped because will be passed to WP_Query
						),
					);
					break;
			}
			return $date_query;
		}
	}
}