<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Facebook Counter.
 *
 * @package /G5P_Facebook_Counter
 * @category Counter
 */
class G5P_Follower_Facebook_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'facebook';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://graph.facebook.com';

    /**
     * Test the counter is available.
     *
     * @param  array $data Widget settings.
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['facebook_id']) && !empty($data['facebook_app_id']) && !empty($data['facebook_app_secret']);
    }

    /**
     * Get access token.
     *
     * @param  array $data Widget settings.
     *
     * @return string
     */
    protected function get_access_token($data)
    {
        $url = sprintf(
            '%s/oauth/access_token?client_id=%s&client_secret=%s&grant_type=client_credentials',
            $this->api_url,
            sanitize_text_field($data['facebook_app_id']),
            sanitize_text_field($data['facebook_app_secret'])
        );
        $access_token = wp_remote_get($url, array('timeout' => 60));

        if (is_wp_error($access_token) || (isset($access_token['response']['code']) && 200 != $access_token['response']['code'])) {
            return '';
        } else {
            $access_token = json_decode($access_token['body'], true);
            return sanitize_text_field($access_token['access_token']);
        }
    }

    /**
     * Get the total.
     * @param  string $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $access_token = $this->get_access_token($data);
                $url = sprintf(
                    '%s%s?fields=fan_count&access_token=%s',
                    $this->api_url . '/v2.7/',
                    sanitize_text_field($data['facebook_id']),
                    $access_token
                );
                $this->connection = wp_remote_get($url, array('timeout' => 60));
                if (is_wp_error($this->connection) || (isset($this->connection['response']['code']) && 200 != $this->connection['response']['code'])) {
                    $this->total = 0;
                } else {
                    $_data = json_decode($this->connection['body'], true);

                    if (isset($_data['fan_count'])) {
                        $count = intval($_data['fan_count']);

                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $facebook_id = !empty($instance['facebook_id']) ? $instance['facebook_id'] : '';
        $facebook_app_id = !empty($instance['facebook_app_id']) ? $instance['facebook_app_id'] : '';
        $facebook_app_secret = !empty($instance['facebook_app_secret']) ? $instance['facebook_app_secret'] : '';
        $data = array(
            'facebook_id' => $facebook_id,
            'facebook_app_id' => $facebook_app_id,
            'facebook_app_secret' => $facebook_app_secret
        );

        $icon = !empty($instance['facebook_icon']) ? $instance['facebook_icon'] : '';
        $icon_color = !empty($instance['facebook_icon_color']) ? $instance['facebook_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://www.facebook.com/' . $facebook_id,
                'label' => __('Fans', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
