<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF GitHub Counter.
 *
 * @package /G5P_Github_Counter
 * @category Counter
 */
class G5P_Follower_Github_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'github';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://api.github.com/users/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['github_username']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {

                $this->connection = wp_remote_get($this->api_url . sanitize_text_field($data['github_username']), array('timeout' => 60));
                if (is_wp_error($this->connection) || 200 != $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $_data = json_decode($this->connection['body'], true);
                    if (isset($_data['followers'])) {
                        $count = intval($_data['followers']);
                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }
        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $github_username = !empty($instance['github_username']) ? $instance['github_username'] : '';
        $data = array(
            'github_username'=>$github_username
        );
        $icon = !empty($instance['github_icon']) ? $instance['github_icon'] : '';
        $icon_color = !empty($instance['github_icon_color']) ? $instance['github_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'icon' => $icon,
                'data' => $data,
                'url' => 'https://github.com/' . $github_username,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,

            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
