<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Google+ Counter.
 *
 * @package /G5P_GooglePlus_Counter
 * @category Counter
 */
class G5P_Follower_GooglePlus_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'googleplus';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://www.googleapis.com/plus/v1/people/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return (!empty($data['googleplus_id']) && !empty($data['googleplus_api_key']));
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $this->connection = wp_remote_get($this->api_url . $data['googleplus_id'] . '?key=' . $data['googleplus_api_key'], array('timeout' => 60));
                if (is_wp_error($this->connection) || '400' <= $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $_data = json_decode($this->connection['body'], true);

                    if (isset($_data['circledByCount'])) {
                        $count = intval($_data['circledByCount']);

                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }
        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $googleplus_id = !empty($instance['googleplus_id']) ? $instance['googleplus_id'] : '';
        $googleplus_api_key = !empty($instance['googleplus_api_key']) ? $instance['googleplus_api_key'] : '';
        $data = array(
            'googleplus_id'=>$googleplus_id,
            'googleplus_api_key'=>$googleplus_api_key
        );
        $icon = !empty($instance['googleplus_icon']) ? $instance['googleplus_icon'] : '';
        $icon_color = !empty($instance['googleplus_icon_color']) ? $instance['googleplus_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id'         => $this->id,
                'icon'       => $icon,
                'data' =>  $data,
                'url'        => 'https://plus.google.com/' . $googleplus_id,
                'label'      => __('Followers', 'achilles-framework'),
                'instance'   => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
