<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Instagram Counter.
 *
 * @package /G5P_Instagram_Counter
 * @category Counter
 */
class G5P_Follower_Instagram_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'instagram';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://api.instagram.com/v1/users/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['instagram_user_id']) && !empty($data['instagram_access_token']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $this->connection = wp_remote_get($this->api_url . $data['instagram_user_id'] . '/?access_token=' . $data['instagram_access_token'], array('timeout' => 60));
                if (is_wp_error($this->connection) || '400' <= $this->connection['response']['code']) {
                    $this->total = 0;

                } else {
                    $response = json_decode($this->connection['body'], true);

                    if (
                        isset($response['meta']['code'])
                        && 200 == $response['meta']['code']
                        && isset($response['data']['counts']['followed_by'])
                    ) {
                        $count = intval($response['data']['counts']['followed_by']);

                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $instagram_username = !empty($instance['instagram_username']) ? $instance['instagram_username'] : '';
        $instagram_user_id = !empty($instance['instagram_user_id']) ? $instance['instagram_user_id'] : '';
        $instagram_access_token = !empty($instance['instagram_access_token']) ? $instance['instagram_access_token'] : '';
        $data = array(
            'instagram_user_id' => $instagram_user_id,
            'instagram_access_token' => $instagram_access_token
        );
        $icon = !empty($instance['instagram_icon']) ? $instance['instagram_icon'] : '';
        $icon_color = !empty($instance['instagram_icon_color']) ? $instance['instagram_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://instagram.com/' . $instagram_username,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
