<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF LinkedIn Counter.
 *
 * @package /G5P_LinkedIn_Counter
 * @category Counter
 */
class G5P_Follower_LinkedIn_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'linkedin';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://api.linkedin.com/v1/companies/%s/num-followers?format=json';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['linkedin_company_id']) && !empty($data['linkedin_access_token']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $params = array(
                    'timeout' => 60,
                    'headers' => array(
                        'Authorization' => 'Bearer ' . sanitize_text_field($data['linkedin_access_token'])
                    )
                );

                $this->connection = wp_remote_get(sprintf($this->api_url, sanitize_text_field($data['linkedin_company_id'])), $params);
                if (is_wp_error($this->connection) || 200 != $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $count = intval($this->connection['body']);

                    if (0 < $count) {
                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $linkedin_company_id = !empty($instance['linkedin_company_id']) ? $instance['linkedin_company_id'] : '';
        $linkedin_access_token = !empty($instance['linkedin_access_token']) ? $instance['linkedin_access_token'] : '';
        $data = array(
            'linkedin_company_id' => $linkedin_company_id,
            'linkedin_access_token' => $linkedin_access_token
        );
        $icon = !empty($instance['linkedin_icon']) ? $instance['linkedin_icon'] : '';
        $icon_color = !empty($instance['linkedin_icon_color']) ? $instance['linkedin_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://www.linkedin.com/company/' . $linkedin_company_id,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
