<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Pinterest Counter.
 *
 * @package /G5P_Pinterest_Counter
 * @category Counter
 */
class G5P_Follower_Pinterest_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'pinterest';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://www.pinterest.com/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['pinterest_username']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $this->connection = wp_remote_get($this->api_url . sanitize_text_field($data['pinterest_username']), array('timeout' => 60));

                if (is_wp_error($this->connection)) {
                    $this->total = 0;
                } else {
                    $count = 0;
                    if (200 == $this->connection['response']['code']) {
                        $tags = array();
                        $regex = '/property\=\"pinterestapp:followers\" name\=\"pinterestapp:followers\" content\=\"(.*?)" data-app/';
                        preg_match($regex, $this->connection['body'], $tags);
                        $count = intval($tags[1]);
                    }

                    if (0 < $count) {
                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }

                    // Just to make the system report more clear...
                    $this->connection['body'] = '{"followers":' . $count . '}';
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $pinterest_username = !empty($instance['pinterest_username']) ? $instance['pinterest_username'] : '';
        $data = array(
            'pinterest_username' => $pinterest_username
        );
        $icon = !empty($instance['pinterest_icon']) ? $instance['pinterest_icon'] : '';
        $icon_color = !empty($instance['pinterest_icon_color']) ? $instance['pinterest_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://www.pinterest.com/' . $pinterest_username,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
