<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF SoundCloud Counter.
 *
 * @package /G5P_SoundCloud_Counter
 * @category Counter
 */
class G5P_Follower_SoundCloud_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'soundcloud';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://api.soundcloud.com/users/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return (!empty($data['soundcloud_username']) && !empty($data['soundcloud_client_id']));
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $this->connection = wp_remote_get($this->api_url . $data['soundcloud_username'] . '.json?client_id=' . $data['soundcloud_client_id'], array('timeout' => 60));

                if (is_wp_error($this->connection) || '400' <= $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $response = json_decode($this->connection['body'], true);

                    if (isset($response['followers_count'])) {
                        $count = intval($response['followers_count']);

                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $soundcloud_username = !empty($instance['soundcloud_username']) ? $instance['soundcloud_username'] : '';
        $soundcloud_client_id = !empty($instance['soundcloud_client_id']) ? $instance['soundcloud_client_id'] : '';
        $data = array(
            'soundcloud_username' => $soundcloud_username,
            'soundcloud_client_id' => $soundcloud_client_id
        );
        $icon = !empty($instance['soundcloud_icon']) ? $instance['soundcloud_icon'] : '';
        $icon_color = !empty($instance['soundcloud_icon_color']) ? $instance['soundcloud_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => join(',', $data),
                'icon' => $icon,
                'url' => 'https://soundcloud.com/' . $soundcloud_username,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
