<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Steam Counter.
 *
 * @package  G5P_Steam_Counter
 * @category Counter
 * @author   Claudio Sanches
 */
class G5P_Follower_Steam_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'steam';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://steamcommunity.com/groups/';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['steam_group_name']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $this->connection = wp_remote_get($this->api_url . $data['steam_group_name'] . '/memberslistxml/?xml=1', array('timeout' => 60));
                if (is_wp_error($this->connection) || '400' <= $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    try {
                        $xml = @new SimpleXmlElement($this->connection['body'], LIBXML_NOCDATA);
                        $count = intval($xml->groupDetails->memberCount);

                        $this->total = $count;
                    } catch (Exception $e) {
                        $this->total = 0;
                    }
                }
            }
        }
        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $steam_group_name = !empty($instance['steam_group_name']) ? $instance['steam_group_name'] : '';
        $data = array(
            'steam_group_name' => $steam_group_name
        );
        $icon = !empty($instance['steam_icon']) ? $instance['steam_icon'] : '';
        $icon_color = !empty($instance['steam_icon_color']) ? $instance['steam_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://steamcommunity.com/groups/' . $steam_group_name,
                'label' => __('Members', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
