<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF Vimeo Counter.
 *
 * @package /G5P_Vimeo_Counter
 * @category Counter
 */
class G5P_Follower_Vimeo_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'vimeo';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://vimeo.com/api/v2/%s/info.json';

    /**
     * Test the counter is available.
     *
     * @param  array $instance Widget settings.
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['vimeo_username']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {

                $this->connection = wp_remote_get(sprintf($this->api_url, sanitize_text_field($data['vimeo_username'])), array('timeout' => 60));
                if (is_wp_error($this->connection) || 200 != $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $_data = json_decode($this->connection['body'], true);
                    if (isset($_data['total_contacts'])) {
                        $count = intval($_data['total_contacts']);
                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $vimeo_username = !empty($instance['vimeo_username']) ? $instance['vimeo_username'] : '';
        $data = array(
            'vimeo_username' => $vimeo_username
        );
        $icon = !empty($instance['vimeo_icon']) ? $instance['vimeo_icon'] : '';
        $icon_color = !empty($instance['vimeo_icon_color']) ? $instance['vimeo_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://vimeo.com/' . $vimeo_username,
                'label' => __('Followers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
