<?php

if (!defined('ABSPATH')) {
    exit; // Exit if accessed directly.
}

/**
 * GSF YouTube Counter.
 *
 * @package /G5P_YouTube_Counter
 * @category Counter
 */
class G5P_Follower_YouTube_Counter extends G5P_Followers_Counter
{

    /**
     * Counter ID.
     *
     * @var string
     */
    public $id = 'youtube';

    /**
     * API URL.
     *
     * @var string
     */
    protected $api_url = 'https://www.googleapis.com/youtube/v3/channels';

    /**
     * Test the counter is available.
     *
     * @param  array $data
     *
     * @return bool
     */
    public function is_available($data)
    {
        return !empty($data['youtube_channel_id']) && !empty($data['youtube_api_key']);
    }

    /**
     * Get the total.
     *
     * @param  array $data
     *
     * @return int
     */
    public function get_total($data)
    {
        if (is_array($data)&&count($data) > 0) {
            if ($this->is_available($data)) {
                $params = array('sslverify' => false, 'timeout' => 60);
                $url = sprintf(
                    '%s?part=statistics&id=%s&key=%s',
                    $this->api_url,
                    sanitize_text_field($data['youtube_channel_id']),
                    sanitize_text_field($data['youtube_api_key'])
                );
                $this->connection = wp_remote_get($url, $params);
                if (is_wp_error($this->connection) || '400' <= $this->connection['response']['code']) {
                    $this->total = 0;
                } else {
                    $_data = json_decode($this->connection['body'], true);
                    if (isset($_data['items'][0]['statistics']['subscriberCount'])) {
                        $count = intval($_data['items'][0]['statistics']['subscriberCount']);
                        $this->total = $count;
                    } else {
                        $this->total = 0;
                    }
                }
            }
        }

        return $this->total;
    }

    /**
     * Get conter view.
     *
     * @param  array $instance Widget settings.
     *
     * @return string
     */
    public function get_view($instance)
    {
        $youtube_channel_id = !empty($instance['youtube_channel_id']) ? $instance['youtube_channel_id'] : '';
        $youtube_api_key = !empty($instance['youtube_api_key']) ? $instance['youtube_api_key'] : '';
        $data = array(
            'youtube_channel_id' => $youtube_channel_id,
            'youtube_api_key' => $youtube_api_key
        );
        $icon = !empty($instance['youtube_icon']) ? $instance['youtube_icon'] : '';
        $icon_color = !empty($instance['youtube_icon_color']) ? $instance['youtube_icon_color'] : '';
        ob_start();
        G5P()->helper()->getTemplate('widgets/followers/inc/templates/get-view-li', array(
                'id' => $this->id,
                'data' => $data,
                'icon' => $icon,
                'url' => 'https://www.youtube.com/channel/' . $youtube_channel_id,
                'label' => __('Subscribers', 'achilles-framework'),
                'instance' => $instance,
                'icon_color' => $icon_color,
            )
        );
        $content = ob_get_clean();
        return $content;
    }
}
