<?php
if (!defined('ABSPATH')) {
	exit;
//	Exit if accessed directly
}
if (!class_exists('G5P_Widget_Heading')) {
	class G5P_Widget_Heading extends GSF_Widget
	{
		public function __construct()
		{
			$this->widget_cssclass = 'widget-heading';
			$this->widget_id = 'gsf-heading';
			$this->widget_name = esc_html__('G5Plus: Heading', 'achilles-framework');
			
			$category = array();
			$categories = get_categories(array('hide_empty' => '1'));
			if (is_array($categories)) {
				foreach ($categories as $cat) {
					$category[$cat->name] = $cat->slug;
				}
			}
			
			$this->settings = array(
				'fields' => array(
					array(
						'id'      => 'title',
						'title'   => esc_html__('Title:', 'achilles-framework'),
						'type'    => 'text',
						'default' => '',
					),
					array(
						'id'      => 'heading_layout',
						'type'    => 'image_set',
						'title'   => esc_html__('Heading Layout', 'achilles-framework'),
						'default' => 'style-1',
						'options' => array(
							'style-1' => array(
								'label' => esc_html__('Heading Style 1', 'achilles-framework'),
								'img'   => G5P()->pluginUrl('assets/images/theme-options/heading-style-1.jpg'),
							),
							'style-2' => array(
								'label' => esc_html__('Heading Style 2', 'achilles-framework'),
								'img'   => G5P()->pluginUrl('assets/images/theme-options/heading-style-2.jpg'),
							),
							'style-3' => array(
								'label' => esc_html__('Heading Style 3', 'achilles-framework'),
								'img'   => G5P()->pluginUrl('assets/images/theme-options/heading-style-3.jpg'),
							),
							'style-4' => array(
								'label' => esc_html__('Heading Style 4', 'achilles-framework'),
								'img'   => G5P()->pluginUrl('assets/images/theme-options/heading-style-4.jpg'),
							)
						)
					),
					array(
						'id'    => 'sub_title',
						'type'  => 'text',
						'title' => esc_html__('Sub Title', 'achilles-framework'),
						'value' => base64_encode(''),
					),
					array(
						'id'    => 'heading_title',
						'type'  => 'text',
						'title' => esc_html__('Title', 'achilles-framework'),
						'value' => base64_encode(''),
					),
					array(
						'id'      => 'text_color',
						'title'   => esc_html__('Text Color', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'text-accent',
						'options' => array(
							'text-accent' => esc_html__('Accent', 'achilles-framework'),
							'text-black'  => esc_html__('Black', 'achilles-framework'),
							'text-white'  => esc_html__('White', 'achilles-framework'),
						)
					),
					array(
						'id'      => 'text_size',
						'title'   => esc_html__('Text Size', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'text-small',
						'options' => array(
							'text-small'  => esc_html__('Small', 'achilles-framework'),
							'text-normal' => esc_html__('Normal', 'achilles-framework'),
							'text-large'  => esc_html__('Large', 'achilles-framework'),
						)
					),
					
					array(
						'id'      => 'text_align',
						'title'   => esc_html__('Text Alignment', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'text-left',
						'options' => array(
							'text-left'   => esc_html__('Left', 'achilles-framework'),
							'text-center' => esc_html__('Center', 'achilles-framework'),
							'text-right'  => esc_html__('Right', 'achilles-framework'),
						)
					),
				),
			);
			parent::__construct();
		}
		
		function widget($args, $instance)
		{
			extract($args, EXTR_SKIP);
			$title = (!empty($instance['title'])) ? $instance['title'] : '';
			$title = apply_filters('widget_title', $title, $instance, $this->id_base);
			$heading_layout = (!empty($instance['heading_layout'])) ? $instance['heading_layout'] : 'style-1';
			$sub_title = (!empty($instance['sub_title'])) ? $instance['sub_title'] : '';
			$heading_title = (!empty($instance['heading_title'])) ? $instance['heading_title'] : '';
			$text_size = (!empty($instance['text_size'])) ? $instance['text_size'] : 'text-small';
			$text_color = (!empty($instance['text_color'])) ? $instance['text_color'] : 'text-accent';
			$text_align = (!empty($instance['text_align'])) ? $instance['text_align'] : 'text-left';
			
			
			$heading_class = 'widget-heading-'.random_int( 1000, 9999 );
			
			$wrapper_classes = array(
				'widget-heading',
				$heading_layout,
				$text_align,
				$text_color,
				$heading_class,
			);
			
			$wrapper_class = implode(' ', array_filter($wrapper_classes));
			
			$title_size = 'fs-18';
			$sub_title_size = 'fs-14';
			
			if ($text_size == 'text-normal') {
				$title_size = 'fs-24';
				$sub_title_size = 'fs-16';
			}
			if ($text_size == 'text-large') {
				$title_size = 'fs-30';
				$sub_title_size = 'fs-18';
			}
			
			echo wp_kses_post($args['before_widget']);
			if ($title):
				echo wp_kses_post($args['before_title'] . $title . $args['after_title']);
			endif;
			?>
			<div class="<?php echo esc_attr($wrapper_class) ?>">
				<div class="gf-heading-content">
					<?php if (!empty($sub_title)): ?>
						<span class="sub-title fw-bold <?php echo esc_attr($sub_title_size); ?>"><?php echo wp_kses_post($sub_title); ?></span>
					<?php endif; ?>
					<?php if (!empty($heading_title)): ?>
						<h4 class="title body-font <?php echo esc_attr($title_size); ?>">
							<span><?php echo wp_kses_post($heading_title); ?></span></h4>
					<?php endif; ?>
				</div>
			</div>
			<?php
			echo wp_kses_post($args['after_widget']);
		}
	}
}
