<?php
if (!defined('ABSPATH')) {
	exit; // Exit if accessed directly
}
if (!class_exists('G5P_Widget_New_Magazine')) {
	class G5P_Widget_New_Magazine extends GSF_Widget
	{
		public function __construct()
		{
			$this->widget_cssclass = 'widget-new-magazine';
			$this->widget_id = 'gsf-new-magazine';
			$this->widget_name = esc_html__('G5Plus: New Magazine', 'achilles-framework');
			
			$this->settings = array(
				'fields' => array(
					array(
						'id'      => 'title',
						'type'    => 'text',
						'default' => '',
						'title'   => esc_html__('Title:', 'achilles-framework')
					),
					array(
						'id'    => 'image',
						'title' => esc_html__('Image:', 'achilles-framework'),
						'type'  => 'image',
						'sort'  => true,
					),
					array(
						'id'         => 'width',
						'type'       => 'text',
						'input_type' => 'number',
						'default'    => '110',
						'title'      => esc_html__('Image Width', 'achilles-framework')
					),
					array(
						'id'      => 'subscribe_sub_title',
						'type'    => 'text',
						'default' => '',
						'title'   => esc_html__('New Magazine Sub Title:', 'achilles-framework')
					),
					array(
						'id'      => 'subscribe_title',
						'type'    => 'text',
						'default' => '',
						'title'   => esc_html__('New Magazine Title:', 'achilles-framework')
					),
					array(
						'id'      => 'button_text',
						'title'   => esc_html__('Button Text', 'achilles-framework'),
						'type'    => 'text',
						'default' => '',
					),
					array(
						'id'      => 'link',
						'title'   => esc_html__('Url (Link):', 'achilles-framework'),
						'type'    => 'text',
						'default' => '',
					),
					
					array(
						'id'      => 'layout_style',
						'title'   => esc_html__('Layout Style', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'img-left',
						'options' => array(
							'img-left'         => esc_html__('Image Left', 'achilles-framework'),
							'img-left-middle'  => esc_html__('Image Left - Content Middle', 'achilles-framework'),
							'img-right'        => esc_html__('Image Right', 'achilles-framework'),
							'img-right-middle' => esc_html__('Image Right - Content Middle', 'achilles-framework'),
						)
					),
					array(
						'id'      => 'text_size',
						'title'   => esc_html__('Text Size', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'text-small',
						'options' => array(
							'text-small'  => esc_html__('Small', 'achilles-framework'),
							'text-normal' => esc_html__('Normal', 'achilles-framework'),
						)
					),
					array(
						'id'      => 'text_color',
						'title'   => esc_html__('Text Color', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'text-dark',
						'options' => array(
							'text-dark'  => esc_html__('Dark', 'achilles-framework'),
							'text-light' => esc_html__('Light', 'achilles-framework'),
						)
					),
					array(
						'type'    => 'select',
						'title'   => esc_html__('Button Style', 'achilles-framework'),
						'id'      => 'button_style',
						'options' => array(
							'classic' => esc_html__('Classic', 'achilles-framework'),
							'outline' => esc_html__('Outline', 'achilles-framework'),
							'3d'      => esc_html__('3d', 'achilles-framework'),
							'normal'  => esc_html__('Normal', 'achilles-framework'),
						),
						'default' => 'classic',
					),
					
					array(
						'id'      => 'size',
						'title'   => esc_html__('Button Size', 'achilles-framework'),
						'type'    => 'select',
						'default' => 'xs',
						'options' => array(
							'xs'  => esc_html__('Mini', 'achilles-framework'),
							'sm'  => esc_html__('Small', 'achilles-framework'),
							'md'  => esc_html__('Normal', 'achilles-framework'),
							'lg'  => esc_html__('Large', 'achilles-framework'),
							'xl'  => esc_html__('Extra Large', 'achilles-framework'),
							'xxl' => esc_html__('Extra Extra Large', 'achilles-framework'),
						)
					),
				)
			);
			
			parent::__construct();
		}
		
		public function widget($args, $instance)
		{
			extract($args, EXTR_SKIP);
			$title = (!empty($instance['title'])) ? $instance['title'] : '';
			$title = apply_filters('widget_title', $title, $instance, $this->id_base);
			$image = apply_filters('widget_image', $instance['image']);
			$width = (!empty($instance['width'])) ? $instance['width'] : '';
			$subscribe_sub_title = (!empty($instance['subscribe_sub_title'])) ? $instance['subscribe_sub_title'] : '';
			$subscribe_title = (!empty($instance['subscribe_title'])) ? $instance['subscribe_title'] : '';
			$button_text = (!empty($instance['button_text'])) ? $instance['button_text'] : '';
			$layout_style = (!empty($instance['layout_style'])) ? $instance['layout_style'] : 'img-left';
			$text_size = (!empty($instance['text_size'])) ? $instance['text_size'] : 'text-small';
			$text_color = (!empty($instance['text_color'])) ? $instance['text_color'] : 'text-dark';
			$button_style = (!empty($instance['button_style'])) ? $instance['button_style'] : 'classic';
			$size = (!empty($instance['size'])) ? $instance['size'] : 'lg';
			$link = $image_url = $attachment_title = "";
			
			$wrapper_classes = array(
				'widget-new-magazine-content',
				$layout_style,
				$text_size,
				$text_color,
				'clearfix'
			);
			$wrapper_class = implode(' ', array_filter($wrapper_classes));
			
			$button_class = "btn btn-accent btn-classic btn-square btn-{$size} btn-{$button_style}";
			if ($button_style == 'normal') {
				$button_class = 'btn-normal';
			}
			
			if ($layout_style == 'img-left-middle') {
				$margin = $width + 20;
				$new_magazine_content = <<<CSS
			.widget-new-magazine-content.img-left-middle .new-magazine-content {
				margin-left: {$margin}px;
			}
			.rtl .widget-new-magazine-content.img-left-middle .new-magazine-content {
							margin-right: {$margin}px;
							margin-left: 0;
						}

CSS;
				GSF()->customCss()->addCss($new_magazine_content);
			}
			
			if ($layout_style == 'img-right-middle') {
				$margin = $width + 20;
				$new_magazine_content = <<<CSS
			.widget-new-magazine-content.img-right-middle .new-magazine-content {
				margin-right: {$margin}px;
			}
			 .rtl .widget-new-magazine-content.img-right-middle .new-magazine-content {
				margin-left: {$margin}px;
						margin-right: 0;
			}
CSS;
				GSF()->customCss()->addCss($new_magazine_content);
			}
			
			if (!empty($instance['link'])) {
				$link = $instance['link'];
			}
			
			if (empty($image['id'])) {
				$image = '';
			} else {
				$image_url = $image['url'];
				$attachment_title = get_the_title($image['id']);
			}
			?>
			
			<?php echo wp_kses_post($args['before_widget']);
			if ($title) {
				echo wp_kses_post($args['before_title'] . $title . $args['after_title']);
			}
			?>
			<div class="<?php echo esc_attr($wrapper_class) ?>">
				<?php if (!empty($image)):
					$alt_image = (!empty($alt)) ? $alt : $attachment_title;
					?>
					<img style="width: <?php echo esc_attr($width); ?>px" alt="<?php echo wp_kses_post($alt_image) ?>"
						 src="<?php echo esc_url($image_url); ?>"/>
				<?php endif; ?>
				<div class="new-magazine-content">
					<?php if ($subscribe_sub_title) : ?>
						<span class="gf-new-magazine-sub-title accent-color"><?php echo wp_kses_post($subscribe_sub_title); ?></span>
					<?php endif; ?>
					<?php if ($subscribe_title) : ?>
						<h3 class="gf-new-magazine-title"><?php echo wp_kses_post($subscribe_title); ?></h3>
					<?php endif; ?>
					<?php if ($link) : ?>
						<a class="<?php echo esc_attr($button_class); ?>"
						   href="<?php echo esc_url($link); ?>"
						   title="<?php echo esc_html($subscribe_title); ?>"><?php echo esc_html($button_text); ?></a>
					<?php else: ?>
						<button class="<?php echo esc_attr($button_class); ?>"><?php echo esc_html($button_text); ?></button>
					<?php endif; ?>
				</div>
			</div>
			<?php echo wp_kses_post($args['after_widget']);
		}
	}
}